@@ -309,8 +309,6 @@ double xyCoordToTemperature(const std::array<double, 2>& white_xy)
         { 600, 0.33724, 0.36051, -116.45 }
     };
 
-    constexpr double tint_scale = -3000.0;
-
     double res = 0;
 
     // Convert to uv space.
@@ -406,6 +404,7 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
     has_tone_curve(false),
     has_baseline_exposure_offset(false),
     will_interpolate(false),
+    valid(false),
     baseline_exposure_offset(0.0)
 {
     constexpr int tiff_float_size = 4;
@@ -691,6 +690,11 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
 
     FILE* const file = g_fopen(filename.c_str(), "rb");
 
+    if (file == nullptr) {
+        printf ("Unable to load DCP profile '%s' !", filename.c_str());
+        return;
+    }
+
     std::unique_ptr<TagDirectory> tagDir(ExifManager::parseTIFF(file, false));
 
     Tag* tag = tagDir->getTag(toUnderlying(TagKey::CALIBRATION_ILLUMINANT_1));
@@ -738,6 +742,7 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
 
     if (!tag) {
         std::cerr << "DCP '" << filename << "' is missing 'ColorMatrix1'. Skipped." << std::endl;
+        fclose(file);
         return;
     }
 
@@ -840,7 +845,7 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
             // Saturation maps. Need to be unwinded.
             tag = tagDir->getTag(toUnderlying(TagKey::PROFILE_HUE_SAT_MAP_DATA_2));
 
-            for (int i = 0; i < delta_info.array_count; ++i) {
+            for (unsigned int i = 0; i < delta_info.array_count; ++i) {
                 deltas_2[i].hue_shift = tag->toDouble((i * 3) * tiff_float_size);
                 deltas_2[i].sat_scale = tag->toDouble((i * 3 + 1) * tiff_float_size);
                 deltas_2[i].val_scale = tag->toDouble((i * 3 + 2) * tiff_float_size);
@@ -935,6 +940,8 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
     if (file) {
         fclose(file);
     }
+
+    valid = true;
 }
 
 DCPProfile::~DCPProfile()
@@ -988,7 +995,7 @@ void DCPProfile::apply(
 ) const
 {
 
-    const TMatrix work_matrix = iccStore->workingSpaceInverseMatrix(working_space);
+    const TMatrix work_matrix = ICCStore::getInstance()->workingSpaceInverseMatrix(working_space);
 
     const Matrix xyz_cam = makeXyzCam(white_balance, pre_mul, cam_wb_matrix, preferred_illuminant); // Camera RGB to XYZ D50 matrix
 
@@ -1015,8 +1022,8 @@ void DCPProfile::apply(
         #pragma omp parallel for
 #endif
 
-        for (int y = 0; y < img->height; ++y) {
-            for (int x = 0; x < img->width; x++) {
+        for (int y = 0; y < img->getHeight(); ++y) {
+            for (int x = 0; x < img->getWidth(); x++) {
                 const float& newr = mat[0][0] * img->r(y, x) + mat[0][1] * img->g(y, x) + mat[0][2] * img->b(y, x);
                 const float& newg = mat[1][0] * img->r(y, x) + mat[1][1] * img->g(y, x) + mat[1][2] * img->b(y, x);
                 const float& newb = mat[2][0] * img->r(y, x) + mat[2][1] * img->g(y, x) + mat[2][2] * img->b(y, x);
@@ -1053,8 +1060,8 @@ void DCPProfile::apply(
         #pragma omp parallel for schedule(dynamic,16)
 #endif
 
-        for (int y = 0; y < img->height; ++y) {
-            for (int x = 0; x < img->width; x++) {
+        for (int y = 0; y < img->getHeight(); ++y) {
+            for (int x = 0; x < img->getWidth(); x++) {
                 float newr = pro_photo[0][0] * img->r(y, x) + pro_photo[0][1] * img->g(y, x) + pro_photo[0][2] * img->b(y, x);
                 float newg = pro_photo[1][0] * img->r(y, x) + pro_photo[1][1] * img->g(y, x) + pro_photo[1][2] * img->b(y, x);
                 float newb = pro_photo[2][0] * img->r(y, x) + pro_photo[2][1] * img->g(y, x) + pro_photo[2][2] * img->b(y, x);
@@ -1110,7 +1117,7 @@ void DCPProfile::setStep2ApplyState(const Glib::ustring& working_space, bool use
         as_out.data->already_pro_photo = false;
         TMatrix mWork;
 
-        mWork = iccStore->workingSpaceMatrix (working_space);
+        mWork = ICCStore::getInstance()->workingSpaceMatrix (working_space);
         memset(as_out.data->pro_photo, 0, sizeof(as_out.data->pro_photo));
 
         for (int i = 0; i < 3; i++)
@@ -1119,7 +1126,7 @@ void DCPProfile::setStep2ApplyState(const Glib::ustring& working_space, bool use
                     as_out.data->pro_photo[i][j] += prophoto_xyz[i][k] * mWork[k][j];
                 }
 
-        mWork = iccStore->workingSpaceInverseMatrix (working_space);
+        mWork = ICCStore::getInstance()->workingSpaceInverseMatrix (working_space);
         memset(as_out.data->work, 0, sizeof(as_out.data->work));
 
         for (int i = 0; i < 3; i++)
@@ -1683,18 +1690,28 @@ void DCPProfile::hsdApply(const HsdTableInfo& table_info, const std::vector<HsbM
     }
 }
 
+bool DCPProfile::isValid()
+{
+    return valid;
+}
+
 DCPStore* DCPStore::getInstance()
 {
     static DCPStore instance;
     return &instance;
 }
 
-void DCPStore::init(const Glib::ustring& rt_profile_dir)
+void DCPStore::init(const Glib::ustring& rt_profile_dir, bool loadAll)
 {
     MyMutex::MyLock lock(mutex);
 
     file_std_profiles.clear();
 
+    if (!loadAll) {
+        profileDir.assign (rt_profile_dir);
+        return;
+    }
+
     if (!rt_profile_dir.empty()) {
         std::deque<Glib::ustring> dirs = {
             rt_profile_dir
@@ -1717,10 +1734,8 @@ void DCPStore::init(const Glib::ustring& rt_profile_dir)
                 return;
             }
 
-            dirname += '/';
-
             for (const Glib::ustring& sname : *dir) {
-                const Glib::ustring fname = dirname + sname;
+                const Glib::ustring fname = Glib::build_filename(dirname, sname);
 
                 if (!Glib::file_test(fname, Glib::FILE_TEST_IS_DIR)) {
                     // File
@@ -1770,9 +1785,12 @@ DCPProfile* DCPStore::getProfile(const Glib::ustring& filename) const
 
     DCPProfile* const res = new DCPProfile(filename);
 
-    if (*res) {
+    if (res->isValid()) {
         // Add profile
         profile_cache[filename] = res;
+        if (options.rtSettings.verbose) {
+            printf("DCP profile '%s' loaded from disk\n", filename.c_str());
+        }
         return res;
     }
 
@@ -1780,15 +1798,25 @@ DCPProfile* DCPStore::getProfile(const Glib::ustring& filename) const
     return nullptr;
 }
 
-DCPProfile* DCPStore::getStdProfile(const Glib::ustring& cam_short_name) const
+DCPProfile* DCPStore::getStdProfile(const Glib::ustring& requested_cam_short_name) const
 {
-    const Glib::ustring name = cam_short_name.uppercase();
+    const Glib::ustring name = requested_cam_short_name.uppercase();
 
     // Warning: do NOT use map.find(), since it does not seem to work reliably here
-    for (const auto& file_std_profile : file_std_profiles)
+    for (const auto& file_std_profile : file_std_profiles) {
         if (file_std_profile.first == name) {
             return getProfile(file_std_profile.second);
         }
+    }
+
+    // profile not found, looking if we're in loadAll=false mode
+    if (!profileDir.empty()) {
+        const Glib::ustring fname = Glib::build_filename(profileDir, requested_cam_short_name + Glib::ustring(".dcp"));
+
+        if (Glib::file_test(fname, Glib::FILE_TEST_EXISTS)) {
+            return getProfile(fname);
+        }
+    }
 
     return nullptr;
 }
