@@ -16,9 +16,11 @@
  *  You should have received a copy of the GNU General Public License
  *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include <strings.h>
+#include <glib/gstdio.h>
+
 #include "imagedata.h"
 #include "iptcpairs.h"
-#include <glib/gstdio.h>
 
 using namespace rtengine;
 
@@ -155,7 +157,8 @@ void ImageData::extractInfo ()
             "SAMSUNG",
             "Mamiya",
             "MOTOROLA",
-            "Leaf"
+            "Leaf",
+            "Panasonic"
         }) {
             if (make.find(corp) != std::string::npos) { // Simplify company names
                 make = corp;
@@ -329,7 +332,7 @@ void ImageData::extractInfo ()
 
                     if (mnote->getTag ("LensData")) {
                         std::string ldata = mnote->getTag ("LensData")->valueToString ();
-                        int pos;
+                        size_t pos;
 
                         if (ldata.size() > 10 && (pos = ldata.find ("Lens = ")) != Glib::ustring::npos) {
                             lens = ldata.substr (pos + 7);
@@ -337,7 +340,7 @@ void ImageData::extractInfo ()
                             if (lens.compare (0, 7, "Unknown")) {
                                 lensOk = true;
                             } else {
-                                int pos = lens.find("$FL$");        // is there a placeholder for focallength?
+                                size_t pos = lens.find("$FL$");        // is there a placeholder for focallength?
 
                                 if(pos != Glib::ustring::npos) {                // then fill in focallength
                                     lens = lens.replace(pos, 4, exif->getTag ("FocalLength")->valueToString ());
@@ -480,6 +483,17 @@ void ImageData::extractInfo ()
                             lens = eq->getTag ("LensType")->valueToString ();
                         }
                     }
+                } else if (mnote && !make.compare (0, 9, "Panasonic")) {
+                    if (mnote->getTag ("LensType")) {
+                        std::string panalens = mnote->getTag("LensType")->valueToString();
+
+                        if (panalens.find("LUMIX") != Glib::ustring::npos) {
+                            lens = "Panasonic " + panalens;
+                        }
+                        else {
+                            lens = panalens;
+                        }
+                    }
                 }
             } else if (exif->getTag ("DNGLensInfo")) {
                 lens = exif->getTag ("DNGLensInfo")->valueToString ();
@@ -564,7 +578,7 @@ std::string ImageMetaData::shutterToString (double shutter)
 
     char buffer[256];
 
-    if (shutter > 0.0 && shutter < 0.9) {
+    if (shutter > 0.0 && shutter <= 0.5) {
         sprintf (buffer, "1/%0.0f", 1.0 / shutter);
     } else {
         sprintf (buffer, "%0.1f", shutter);
