@@ -34,11 +34,10 @@ extern const Settings* settings;
 
 ImProcCoordinator::ImProcCoordinator ()
     : orig_prev(nullptr), oprevi(nullptr), oprevl(nullptr), nprevl(nullptr), previmg(nullptr), workimg(nullptr),
-      ncie(nullptr), imgsrc(nullptr), shmap(nullptr), lastAwbEqual(0.), ipf(&params, true), monitorIntent(RI_RELATIVE),
+      ncie(nullptr), imgsrc(nullptr), shmap(nullptr), lastAwbEqual(0.), lastAwbTempBias(0.0), ipf(&params, true), monitorIntent(RI_RELATIVE),
       softProof(false), gamutCheck(false), scale(10), highDetailPreprocessComputed(false), highDetailRawComputed(false),
       allocated(false), bwAutoR(-9000.f), bwAutoG(-9000.f), bwAutoB(-9000.f), CAMMean(NAN),
 
-      ctColorCurve(),
       hltonecurve(65536),
       shtonecurve(65536),
       tonecurve(65536, 0), //,1);
@@ -48,6 +47,7 @@ ImProcCoordinator::ImProcCoordinator ()
       satcurve(65536, 0),
       lhskcurve(65536, 0),
       clcurve(65536, 0),
+      conversionBuffer(1, 1), 
       wavclCurve(65536, 0),
       clToningcurve(65536, 0),
       cl2Toningcurve(65536, 0),
@@ -81,15 +81,16 @@ ImProcCoordinator::ImProcCoordinator ()
       rCurve(),
       gCurve(),
       bCurve(),
+      ctColorCurve(),
       rcurvehist(256), rcurvehistCropped(256), rbeforehist(256),
       gcurvehist(256), gcurvehistCropped(256), gbeforehist(256),
       bcurvehist(256), bcurvehistCropped(256), bbeforehist(256),
       fw(0), fh(0), tr(0),
       fullw(1), fullh(1),
       pW(-1), pH(-1),
-      plistener(nullptr), imageListener(nullptr), aeListener(nullptr), acListener(nullptr), abwListener(nullptr), actListener(nullptr), adnListener(nullptr), awavListener(nullptr), dehaListener(nullptr), hListener(nullptr),
-      resultValid(false), lastOutputProfile("BADFOOD"), lastOutputIntent(RI__COUNT), lastOutputBPC(false), thread(nullptr), changeSinceLast(0), updaterRunning(false), destroying(false), utili(false), autili(false), wavcontlutili(false),
-      butili(false), ccutili(false), cclutili(false), clcutili(false), opautili(false), conversionBuffer(1, 1), colourToningSatLimit(0.f), colourToningSatLimitOpacity(0.f)
+      plistener(nullptr), imageListener(nullptr), aeListener(nullptr), acListener(nullptr), abwListener(nullptr), awbListener(nullptr), frameCountListener(nullptr), imageTypeListener(nullptr), actListener(nullptr), adnListener(nullptr), awavListener(nullptr), dehaListener(nullptr), hListener(nullptr),
+      resultValid(false), lastOutputProfile("BADFOOD"), lastOutputIntent(RI__COUNT), lastOutputBPC(false), thread(nullptr), changeSinceLast(0), updaterRunning(false), destroying(false), utili(false), autili(false),
+      butili(false), ccutili(false), cclutili(false), clcutili(false), opautili(false), wavcontlutili(false), colourToningSatLimit(0.f), colourToningSatLimitOpacity(0.f)
 {}
 
 void ImProcCoordinator::assign (ImageSource* imgsrc)
@@ -183,8 +184,14 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
 
     progress ("Applying white balance, color correction & sRGB conversion...", 100 * readyphase / numofphases);
 
+    if(frameCountListener) {
+        frameCountListener->FrameCountChanged(imgsrc->getFrameCount(), params.raw.bayersensor.imageNum);
+    }
+
     // raw auto CA is bypassed if no high detail is needed, so we have to compute it when high detail is needed
     if ( (todo & M_PREPROC) || (!highDetailPreprocessComputed && highDetailNeeded)) {
+        imgsrc->setCurrentFrame(params.raw.bayersensor.imageNum);
+
         imgsrc->preprocess( rp, params.lensProf, params.coarse );
         imgsrc->getRAWHistogram( histRedRaw, histGreenRaw, histBlueRaw );
 
@@ -207,6 +214,10 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
     */
     // If high detail (=100%) is newly selected, do a demosaic update, since the last was just with FAST
 
+    if(imageTypeListener) {
+        imageTypeListener->imageTypeChanged(imgsrc->isRAW(), imgsrc->getSensorType() == ST_BAYER, imgsrc->getSensorType() == ST_FUJI_XTRANS);
+    }
+
     if (   (todo & M_RAW)
             || (!highDetailRawComputed && highDetailNeeded)
             || ( params.toneCurve.hrenabled && params.toneCurve.method != "Color" && imgsrc->IsrgbSourceModified())
@@ -214,7 +225,7 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
 
         if (settings->verbose) {
             if (imgsrc->getSensorType() == ST_BAYER) {
-                printf("Demosaic Bayer image using method: %s\n", rp.bayersensor.method.c_str());
+                printf("Demosaic Bayer image n.%d using method: %s\n", rp.bayersensor.imageNum + 1, rp.bayersensor.method.c_str());
             } else if (imgsrc->getSensorType() == ST_FUJI_XTRANS) {
                 printf("Demosaic X-Trans image with using method: %s\n", rp.xtranssensor.method.c_str());
             }
@@ -284,15 +295,17 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
         if (params.wb.method == "Camera") {
             currWB = imgsrc->getWB ();
         } else if (params.wb.method == "Auto") {
-            if (lastAwbEqual != params.wb.equal) {
+            if (lastAwbEqual != params.wb.equal || lastAwbTempBias != params.wb.tempBias) {
                 double rm, gm, bm;
                 imgsrc->getAutoWBMultipliers(rm, gm, bm);
 
                 if (rm != -1.) {
-                    autoWB.update(rm, gm, bm, params.wb.equal);
+                    autoWB.update(rm, gm, bm, params.wb.equal, params.wb.tempBias);
                     lastAwbEqual = params.wb.equal;
+                    lastAwbTempBias = params.wb.tempBias;
                 } else {
                     lastAwbEqual = -1.;
+                    lastAwbTempBias = 0.0;
                     autoWB.useDefaults(params.wb.equal);
                 }
 
@@ -305,6 +318,9 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
 
         params.wb.temperature = currWB.getTemp ();
         params.wb.green = currWB.getGreen ();
+        if(params.wb.method == "Auto" && awbListener) {
+            awbListener->WBChanged(params.wb.temperature, params.wb.green);
+        }
 
         int tr = getCoarseBitMask(params.coarse);
 
@@ -452,13 +468,13 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
         opautili = false;
 
         if(params.colorToning.enabled) {
-            TMatrix wprof = iccStore->workingSpaceMatrix (params.icm.working);
+            TMatrix wprof = ICCStore::getInstance()->workingSpaceMatrix (params.icm.working);
             double wp[3][3] = {
                 {wprof[0][0], wprof[0][1], wprof[0][2]},
                 {wprof[1][0], wprof[1][1], wprof[1][2]},
                 {wprof[2][0], wprof[2][1], wprof[2][2]}
             };
-            TMatrix wiprof = iccStore->workingSpaceInverseMatrix (params.icm.working);
+            TMatrix wiprof = ICCStore::getInstance()->workingSpaceInverseMatrix (params.icm.working);
             double wip[3][3] = {
                 {wiprof[0][0], wiprof[0][1], wiprof[0][2]},
                 {wiprof[1][0], wiprof[1][1], wiprof[1][2]},
@@ -592,6 +608,9 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
 #endif
             lhist16 += lhist16thr;
         }
+#ifdef _OPENMP
+            static_cast<void>(numThreads); // to silence cppcheck warning
+#endif
         CurveFactory::complexLCurve (params.labCurve.brightness, params.labCurve.contrast, params.labCurve.lcurve, lhist16, lumacurve, histLCurve, scale == 1 ? 1 : 16, utili);
     }
 
@@ -796,7 +815,7 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
         MyMutex::MyLock prevImgLock(previmg->getMutex());
 
         try {
-            // Computing the preview image, i.e. converting from WCS->Monitor color space (soft-proofing disabled) or WCS->Output profile->Monitor color space (soft-proofing enabled)
+            // Computing the preview image, i.e. converting from WCS->Monitor color space (soft-proofing disabled) or WCS->Printer profile->Monitor color space (soft-proofing enabled)
             ipf.lab2monitorRgb (nprevl, previmg);
 
             // Computing the internal image for analysis, i.e. conversion from WCS->Output profile
@@ -828,6 +847,7 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall)
         updateLRGBHistograms ();
         hListener->histogramChanged (histRed, histGreen, histBlue, histLuma, histToneCurve, histLCurve, histCCurve, /*histCLurve, histLLCurve,*/ histLCAM, histCCAM, histRedRaw, histGreenRaw, histBlueRaw, histChroma, histLRETI);
     }
+
 }
 
 
@@ -1011,21 +1031,23 @@ void ImProcCoordinator::progress (Glib::ustring str, int pr)
       }*/
 }
 
-bool ImProcCoordinator::getAutoWB (double& temp, double& green, double equal)
+bool ImProcCoordinator::getAutoWB (double& temp, double& green, double equal, double tempBias)
 {
 
     if (imgsrc) {
-        if (lastAwbEqual != equal) {
+        if (lastAwbEqual != equal || lastAwbTempBias != tempBias) {
 // Issue 2500            MyMutex::MyLock lock(minit);  // Also used in crop window
             double rm, gm, bm;
             imgsrc->getAutoWBMultipliers(rm, gm, bm);
 
             if (rm != -1) {
-                autoWB.update(rm, gm, bm, equal);
+                autoWB.update(rm, gm, bm, equal, tempBias);
                 lastAwbEqual = equal;
+                lastAwbTempBias = tempBias;
             } else {
                 lastAwbEqual = -1.;
                 autoWB.useDefaults(equal);
+                lastAwbTempBias = 0.0;
             }
         }
 
@@ -1162,15 +1184,17 @@ void ImProcCoordinator::saveInputICCReference (const Glib::ustring& fname, bool
     if (params.wb.method == "Camera") {
         currWB = imgsrc->getWB ();
     } else if (params.wb.method == "Auto") {
-        if (lastAwbEqual != params.wb.equal) {
+        if (lastAwbEqual != params.wb.equal || lastAwbTempBias != params.wb.tempBias) {
             double rm, gm, bm;
             imgsrc->getAutoWBMultipliers(rm, gm, bm);
 
             if (rm != -1.) {
-                autoWB.update(rm, gm, bm, params.wb.equal);
+                autoWB.update(rm, gm, bm, params.wb.equal, params.wb.tempBias);
                 lastAwbEqual = params.wb.equal;
+                lastAwbTempBias = params.wb.tempBias;
             } else {
                 lastAwbEqual = -1.;
+                lastAwbTempBias = 0.0;
                 autoWB.useDefaults(params.wb.equal);
             }
         }
@@ -1216,8 +1240,8 @@ void ImProcCoordinator::saveInputICCReference (const Glib::ustring& fname, bool
     // image may contain out of range samples, clip them to avoid wrap-arounds
     #pragma omp parallel for
 
-    for(int i = 0; i < im->height; i++) {
-        for(int j = 0; j < im->width; j++) {
+    for(int i = 0; i < im->getHeight(); i++) {
+        for(int j = 0; j < im->getWidth(); j++) {
             im->r(i, j) = CLIP(im->r(i, j));
             im->g(i, j) = CLIP(im->g(i, j));
             im->b(i, j) = CLIP(im->b(i, j));
