@@ -470,6 +470,38 @@ enum ProcEvent {
     EvRetinexgaintransmission = 440,
     EvLskal = 441,
     EvOBPCompens = 442,
+    EvWBtempBias = 443,
+    EvRawImageNum = 444,
+    EvPixelShiftMotion = 445,
+    EvPixelShiftMotionCorrection = 446,
+    EvPixelShiftStddevFactorGreen = 447,
+    EvPixelShiftEperIso = 448,
+    EvPixelShiftNreadIso = 449,
+    EvPixelShiftPrnu = 450,
+    EvPixelshiftShowMotion = 451,
+    EvPixelshiftShowMotionMaskOnly = 452,
+    EvPixelShiftAutomatic = 453,
+    EvPixelShiftNonGreenHorizontal = 454,
+    EvPixelShiftNonGreenVertical = 455,
+    EvPixelShiftNonGreenCross = 456,
+    EvPixelShiftStddevFactorRed = 457,
+    EvPixelShiftStddevFactorBlue = 458,
+    EvPixelShiftGreenAmaze = 459,
+    EvPixelShiftNonGreenAmaze = 460,
+    EvPixelShiftGreen = 461,
+    EvPixelShiftRedBlueWeight = 462,
+    EvPixelShiftBlur = 463,
+    EvPixelShiftSigma = 464,
+    EvPixelShiftSum = 465,
+    EvPixelShiftExp0 = 466,
+    EvPixelShiftHoleFill = 467,
+    EvPixelShiftMedian = 468,
+    EvPixelShiftMedian3 = 469,
+    EvPixelShiftMotionMethod = 470,
+    EvPixelShiftSmooth = 471,
+    EvPixelShiftLmmse = 472,
+    EvPixelShiftEqualBright = 473,
+    EvPixelShiftEqualBrightChannel = 474,
     NUMOFEVENTS
 
 };
