@@ -37,8 +37,6 @@
 #include "../rtgui/ppversion.h"
 #include "improccoordinator.h"
 #include <locale.h>
-//#define BENCHMARK
-#include "StopWatch.h"
 
 
 namespace
@@ -50,7 +48,7 @@ namespace
             return false;
         }
 
-        const std::size_t length =
+        const ssize_t length =
             fdata(raw_image.get_thumbOffset(), raw_image.get_file())[1] != 0xD8 && raw_image.is_ppmThumb()
                 ? raw_image.get_thumbWidth() * raw_image.get_thumbHeight() * (raw_image.get_thumbBPS() / 8) * 3
                 : raw_image.get_thumbLength();
@@ -58,6 +56,74 @@ namespace
         return raw_image.get_thumbOffset() + length <= raw_image.get_file()->size;
     }
 
+
+void scale_colors(rtengine::RawImage *ri, float scale_mul[4], float cblack[4])
+{
+    DCraw::dcrawImage_t image = ri->get_image();
+    if(ri->isBayer()) {
+        const int height = ri->get_iheight();
+        const int width = ri->get_iwidth();
+        for(int row = 0; row < height; ++row) {
+            unsigned c0 = ri->FC(row,0);
+            unsigned c1 = ri->FC(row,1);
+            int col = 0;
+            for(; col < width - 1; col += 2) {
+                float val0 = image[row * width + col][c0];
+                float val1 = image[row * width + col + 1][c1];
+                val0 -= cblack[c0];
+                val1 -= cblack[c1];
+                val0 *= scale_mul[c0];
+                val1 *= scale_mul[c1];
+                image[row * width + col][c0] = rtengine::CLIP(val0);
+                image[row * width + col + 1][c1] = rtengine::CLIP(val1);
+            }
+            if(col < width) { // in case width is odd
+                float val0 = image[row * width + col][c0];
+                val0 -= cblack[c0];
+                val0 *= scale_mul[c0];
+                image[row * width + col][c0] = rtengine::CLIP(val0);
+            }
+        }
+    } else if(ri->isXtrans()) {
+        const int height = ri->get_iheight();
+        const int width = ri->get_iwidth();
+        unsigned c[6];
+        for(int row = 0; row < height; ++row) {
+            for(int i = 0; i < 6; ++i) {
+                c[i] = ri->XTRANSFC(row,i);
+            }
+
+            int col = 0;
+            for(; col < width - 5; col += 6) {
+                for(int i = 0; i < 6; ++i) {
+                    const unsigned ccol = c[i];
+                    float val = image[row * width + col + i][ccol];
+                    val -= cblack[ccol];
+                    val *= scale_mul[ccol];
+                    image[row * width + col + i][ccol] = rtengine::CLIP(val);
+                }
+            }
+            for(; col < width; ++col) { // remaining columns
+                const unsigned ccol = ri->XTRANSFC(row,col);
+                float val = image[row * width + col][ccol];
+                val -= cblack[ccol];
+                val *= scale_mul[ccol];
+                image[row * width + col][ccol] = rtengine::CLIP(val);
+            }
+        }
+    } else {
+        const int size = ri->get_iheight() * ri->get_iwidth();
+        for (int i = 0; i < size; ++i) {
+            for (int j = 0; j < 4; ++j) {
+                float val = image[i][j];
+                val -= cblack[j];
+                val *= scale_mul[j];
+                image[i][j] = rtengine::CLIP(val);
+            }
+        }
+    }
+}
+
 }
 
 extern Options options;
@@ -98,16 +164,16 @@ Thumbnail* Thumbnail::loadFromImage (const Glib::ustring& fname, int &w, int &h,
 
     if (inspectorMode) {
         // Special case, meaning that we want a full sized thumbnail image (e.g. for the Inspector feature)
-        w = img->width;
-        h = img->height;
+        w = img->getWidth();
+        h = img->getHeight();
         tpp->scale = 1.;
     } else {
         if (fixwh == 1) {
-            w = h * img->width / img->height;
-            tpp->scale = (double)img->height / h;
+            w = h * img->getWidth() / img->getHeight();
+            tpp->scale = (double)img->getHeight() / h;
         } else {
-            h = w * img->height / img->width;
-            tpp->scale = (double)img->width / w;
+            h = w * img->getHeight() / img->getWidth();
+            tpp->scale = (double)img->getWidth() / w;
         }
     }
 
@@ -162,6 +228,7 @@ Thumbnail* Thumbnail::loadFromImage (const Glib::ustring& fname, int &w, int &h,
             tpp->greenAWBMul = avg_g / double(n);
             tpp->blueAWBMul  = avg_b / double(n);
             tpp->wbEqual = wbEq;
+            tpp->wbTempBias = 0.0;
 
             cTemp.mul2temp (tpp->redAWBMul, tpp->greenAWBMul, tpp->blueAWBMul, tpp->wbEqual, tpp->autoWBTemp, tpp->autoWBGreen);
         }
@@ -175,7 +242,8 @@ Thumbnail* Thumbnail::loadFromImage (const Glib::ustring& fname, int &w, int &h,
 Thumbnail* Thumbnail::loadQuickFromRaw (const Glib::ustring& fname, RawMetaDataLocation& rml, int &w, int &h, int fixwh, bool rotate, bool inspectorMode)
 {
     RawImage *ri = new RawImage(fname);
-    int r = ri->loadRaw(false, false);
+    unsigned int imageNum = 0;
+    int r = ri->loadRaw(false, imageNum, false);
 
     if( r ) {
         delete ri;
@@ -223,16 +291,16 @@ Thumbnail* Thumbnail::loadQuickFromRaw (const Glib::ustring& fname, RawMetaDataL
 
     if (inspectorMode) {
         // Special case, meaning that we want a full sized thumbnail image (e.g. for the Inspector feature)
-        w = img->width;
-        h = img->height;
+        w = img->getWidth();
+        h = img->getHeight();
         tpp->scale = 1.;
     } else {
         if (fixwh == 1) {
-            w = h * img->width / img->height;
-            tpp->scale = (double)img->height / h;
+            w = h * img->getWidth() / img->getHeight();
+            tpp->scale = (double)img->getHeight() / h;
         } else {
-            h = w * img->height / img->width;
-            tpp->scale = (double)img->width / w;
+            h = w * img->getHeight() / img->getWidth();
+            tpp->scale = (double)img->getWidth() / w;
         }
     }
 
@@ -252,7 +320,7 @@ Thumbnail* Thumbnail::loadQuickFromRaw (const Glib::ustring& fname, RawMetaDataL
         std::string fname = ri->get_filename();
         std::string suffix = fname.length() > 4 ? fname.substr(fname.length() - 3) : "";
 
-        for (int i = 0; i < suffix.length(); i++) {
+        for (unsigned int i = 0; i < suffix.length(); i++) {
             suffix[i] = std::tolower(suffix[i]);
         }
 
@@ -260,8 +328,8 @@ Thumbnail* Thumbnail::loadQuickFromRaw (const Glib::ustring& fname, RawMetaDataL
         if (suffix != "mos" && suffix != "mef" && suffix != "iiq")  {
             tpp->thumbImg->rotate(ri->get_rotateDegree());
             // width/height may have changed after rotating
-            w = tpp->thumbImg->width;
-            h = tpp->thumbImg->height;
+            w = tpp->thumbImg->getWidth();
+            h = tpp->thumbImg->getHeight();
         }
     }
 
@@ -289,7 +357,9 @@ RawMetaDataLocation Thumbnail::loadMetaDataFromRaw (const Glib::ustring& fname)
     rml.ciffLength = -1;
 
     RawImage ri(fname);
-    int r = ri.loadRaw(false);
+    unsigned int imageNum = 0;
+
+    int r = ri.loadRaw(false, imageNum);
 
     if( !r ) {
         rml.exifBase = ri.get_exifBase();
@@ -300,10 +370,12 @@ RawMetaDataLocation Thumbnail::loadMetaDataFromRaw (const Glib::ustring& fname)
     return rml;
 }
 
-Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocation& rml, int &w, int &h, int fixwh, double wbEq, bool rotate)
+Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocation& rml, int &w, int &h, int fixwh, double wbEq, bool rotate, int imageNum)
 {
     RawImage *ri = new RawImage (fname);
-    int r = ri->loadRaw(1, 0);
+    unsigned int tempImageNum = 0;
+
+    int r = ri->loadRaw(1, tempImageNum, 0);
 
     if( r ) {
         delete ri;
@@ -327,17 +399,23 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
     tpp->greenMultiplier = ri->get_pre_mul(1);
     tpp->blueMultiplier = ri->get_pre_mul(2);
 
-    ri->scale_colors();
+    //ri->scale_colors();
+    float pre_mul[4], scale_mul[4], cblack[4];
+    ri->get_colorsCoeff(pre_mul, scale_mul, cblack, false);
+    scale_colors(ri, scale_mul, cblack);
+    
     ri->pre_interpolate();
 
     rml.exifBase = ri->get_exifBase();
     rml.ciffBase = ri->get_ciffBase();
     rml.ciffLength = ri->get_ciffLen();
 
-    tpp->camwbRed = tpp->redMultiplier / ri->get_pre_mul(0);
-    tpp->camwbGreen = tpp->greenMultiplier / ri->get_pre_mul(1);
-    tpp->camwbBlue = tpp->blueMultiplier / ri->get_pre_mul(2);
-    tpp->defGain = 1.0 / min(ri->get_pre_mul(0), ri->get_pre_mul(1), ri->get_pre_mul(2));
+    tpp->camwbRed = tpp->redMultiplier / pre_mul[0]; //ri->get_pre_mul(0);
+    tpp->camwbGreen = tpp->greenMultiplier / pre_mul[1]; //ri->get_pre_mul(1);
+    tpp->camwbBlue = tpp->blueMultiplier / pre_mul[2]; //ri->get_pre_mul(2);
+    //tpp->defGain = 1.0 / min(ri->get_pre_mul(0), ri->get_pre_mul(1), ri->get_pre_mul(2));
+    tpp->defGain = max(scale_mul[0], scale_mul[1], scale_mul[2], scale_mul[3]) / min(scale_mul[0], scale_mul[1], scale_mul[2], scale_mul[3]);
+
     tpp->gammaCorrected = true;
 
     unsigned filter = ri->get_filters();
@@ -466,20 +544,32 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
             int left_margin = ri->get_leftmargin();
             firstgreen += left_margin;
             int top_margin = ri->get_topmargin();
+            int wmax = tmpw;
+            int hmax = tmph;
             if(ri->get_maker() == "Sigma" && ri->DNGVERSION()) { // Hack to prevent sigma dng files from crashing
-                tmpw = (width - 2 - left_margin) / hskip;
-                tmph = (height - 2 - top_margin) / vskip;
+                wmax = (width - 2 - left_margin) / hskip;
+                hmax = (height - 2 - top_margin) / vskip;
             }
 
-            for (int row = 1 + top_margin, y = 0; row < iheight + top_margin  - 1 && y < tmph; row += vskip, y++) {
+            int y = 0;
+            for (int row = 1 + top_margin; row < iheight + top_margin  - 1 && y < hmax; row += vskip, y++) {
                 rofs = row * iwidth;
 
-                for (int col = firstgreen, x = 0; col < iwidth + left_margin - 1 && x < tmpw; col += hskip, x++) {
+                int x = 0;
+                for (int col = firstgreen; col < iwidth + left_margin - 1 && x < wmax; col += hskip, x++) {
                     int ofs = rofs + col;
                     tmpImg->r(y, x) = image[ofs][0];
                     tmpImg->g(y, x) = image[ofs][1];
                     tmpImg->b(y, x) = image[ofs][2];
                 }
+                for (; x < tmpw; ++x) {
+                    tmpImg->r(y, x) = tmpImg->g(y, x) = tmpImg->b(y, x) = 0;
+                }
+            }
+            for (; y < tmph; ++y) {
+                for (int x = 0; x < tmpw; ++x) {
+                    tmpImg->r(y, x) = tmpImg->g(y, x) = tmpImg->b(y, x) = 0;
+                }
             }
         }
     }
@@ -494,8 +584,8 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
 
         for (int row = 0; row < high; row++)
             for (int col = 0; col < wide; col++) {
-                unsigned ur = r = fw + (row - col) * step;
-                unsigned uc = c = (row + col) * step;
+                int ur = r = fw + (row - col) * step;
+                int uc = c = (row + col) * step;
 
                 if (ur > tmph - 2 || uc > tmpw - 2) {
                     continue;
@@ -544,9 +634,9 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
 
 
     if (ri->get_FujiWidth() != 0) {
-        tpp->scale = (double) (height - ri->get_FujiWidth()) / sqrt(0.5) / h;
+        tpp->scale = (double) (height - ri->get_FujiWidth()) * 2.0 / (rotate_90 ? w : h);
     } else {
-        tpp->scale = (double) height / h;
+        tpp->scale = (double) height / (rotate_90 ? w : h);
     }
 
     // generate histogram for auto exposure
@@ -735,6 +825,7 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
     tpp->greenAWBMul = ri->get_rgb_cam(1, 0) * reds + ri->get_rgb_cam(1, 1) * greens + ri->get_rgb_cam(1, 2) * blues;
     tpp->blueAWBMul  = ri->get_rgb_cam(2, 0) * reds + ri->get_rgb_cam(2, 1) * greens + ri->get_rgb_cam(2, 2) * blues;
     tpp->wbEqual = wbEq;
+    tpp->wbTempBias = 0.0;
 
     ColorTemp cTemp;
     cTemp.mul2temp(tpp->redAWBMul, tpp->greenAWBMul, tpp->blueAWBMul, tpp->wbEqual, tpp->autoWBTemp, tpp->autoWBGreen);
@@ -768,21 +859,37 @@ void Thumbnail::init ()
                 cam2xyz[i][j] += xyz_sRGB[i][k] * colorMatrix[k][j];
             }
 
-    camProfile = iccStore->createFromMatrix (cam2xyz, false, "Camera");
+    camProfile = ICCStore::getInstance()->createFromMatrix (cam2xyz, false, "Camera");
 }
 
 Thumbnail::Thumbnail () :
-    iColorMatrix{}, cam2xyz{}, scale(1.0), colorMatrix{}, isRaw(true),
-    camProfile(nullptr), thumbImg(nullptr),
-    camwbRed(1.0), camwbGreen(1.0), camwbBlue(1.0),
-    redAWBMul(-1.0), greenAWBMul(-1.0), blueAWBMul(-1.0),
-    autoWBTemp(2700), autoWBGreen(1.0), wbEqual(-1.0),
-    embProfileLength(0), embProfileData(nullptr), embProfile(nullptr),
-    redMultiplier(1.0), greenMultiplier(1.0), blueMultiplier(1.0),
+    camProfile(nullptr),
+    iColorMatrix{},
+    cam2xyz{},
+    thumbImg(nullptr),
+    camwbRed(1.0),
+    camwbGreen(1.0),
+    camwbBlue(1.0),
+    redAWBMul(-1.0),
+    greenAWBMul(-1.0),
+    blueAWBMul(-1.0),
+    autoWBTemp(2700),
+    autoWBGreen(1.0),
+    wbEqual(-1.0),
+    wbTempBias(0.0),
+    aeHistCompression(3),
+    embProfileLength(0),
+    embProfileData(nullptr),
+    embProfile(nullptr),
+    redMultiplier(1.0),
+    greenMultiplier(1.0),
+    blueMultiplier(1.0),
+    scale(1.0),
     defGain(1.0),
     scaleForSave(8192),
     gammaCorrected(false),
-    aeHistCompression(3)
+    colorMatrix{},
+    isRaw(true)
 {
 }
 
@@ -810,9 +917,9 @@ IImage8* Thumbnail::quickProcessImage (const procparams::ProcParams& params, int
 
     if (params.coarse.rotate == 90 || params.coarse.rotate == 270) {
         rwidth = rheight;
-        rheight = thumbImg->height * rwidth / thumbImg->width;
+        rheight = thumbImg->getHeight() * rwidth / thumbImg->getWidth();
     } else {
-        rwidth = thumbImg->width * rheight / thumbImg->height;
+        rwidth = thumbImg->getWidth() * rheight / thumbImg->getHeight();
     }
 
     Image8* baseImg = resizeTo<Image8>(rwidth, rheight, interp, thumbImg);
@@ -836,14 +943,14 @@ IImage8* Thumbnail::quickProcessImage (const procparams::ProcParams& params, int
 IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rheight, TypeInterpolation interp, std::string camName,
                                   double focalLen, double focalLen35mm, float focusDist, float shutter, float fnumber, float iso, std::string expcomp_, double& myscale)
 {
-    BENCHFUN
-
     // check if the WB's equalizer value has changed
-    if (wbEqual < (params.wb.equal - 5e-4) || wbEqual > (params.wb.equal + 5e-4)) {
+    if (wbEqual < (params.wb.equal - 5e-4) || wbEqual > (params.wb.equal + 5e-4) || wbTempBias < (params.wb.tempBias - 5e-4) || wbTempBias > (params.wb.tempBias + 5e-4)) {
         wbEqual = params.wb.equal;
+        wbTempBias = params.wb.tempBias;
         // recompute the autoWB
         ColorTemp cTemp;
         cTemp.mul2temp (redAWBMul, greenAWBMul, blueAWBMul, wbEqual, autoWBTemp, autoWBGreen);
+        autoWBTemp += autoWBTemp * wbTempBias;
     }
 
     // compute WB multipliers
@@ -869,7 +976,6 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
     gm = camwbGreen / gm;
     bm = camwbBlue / bm;
     double mul_lum = 0.299 * rm + 0.587 * gm + 0.114 * bm;
-    double logDefGain = 0.0;
     float rmi, gmi, bmi;
 
     rmi = rm * defGain / mul_lum;
@@ -889,9 +995,9 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 
     if (params.coarse.rotate == 90 || params.coarse.rotate == 270) {
         rwidth = rheight;
-        rheight = int(size_t(thumbImg->height) * size_t(rwidth) / size_t(thumbImg->width));
+        rheight = int(size_t(thumbImg->getHeight()) * size_t(rwidth) / size_t(thumbImg->getWidth()));
     } else {
-        rwidth = int(size_t(thumbImg->width) * size_t(rheight) / size_t(thumbImg->height));
+        rwidth = int(size_t(thumbImg->getWidth()) * size_t(rheight) / size_t(thumbImg->getHeight()));
     }
 
 
@@ -899,8 +1005,8 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 
     if (params.coarse.rotate) {
         baseImg->rotate (params.coarse.rotate);
-        rwidth = baseImg->width;
-        rheight = baseImg->height;
+        rwidth = baseImg->getWidth();
+        rheight = baseImg->getHeight();
     }
 
     if (params.coarse.hflip) {
@@ -940,17 +1046,16 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         StdImageSource::colorSpaceConversion (baseImg, params.icm, embProfile, thumbImg->getSampleFormat());
     }
 
-    int fw = baseImg->width;
-    int fh = baseImg->height;
+    int fw = baseImg->getWidth();
+    int fh = baseImg->getHeight();
     //ColorTemp::CAT02 (baseImg, &params)   ;//perhaps not good!
 
     ImProcFunctions ipf (&params, false);
-    ipf.setScale (sqrt(double(fw * fw + fh * fh)) / sqrt(double(thumbImg->width * thumbImg->width + thumbImg->height * thumbImg->height))*scale);
-    ipf.updateColorProfiles (options.rtSettings.monitorProfile, options.rtSettings.monitorIntent, false, false);
+    ipf.setScale (sqrt(double(fw * fw + fh * fh)) / sqrt(double(thumbImg->getWidth() * thumbImg->getWidth() + thumbImg->getHeight() * thumbImg->getHeight()))*scale);
+    ipf.updateColorProfiles (ICCStore::getInstance()->getDefaultMonitorProfileName(), options.rtSettings.monitorIntent, false, false);
 
     LUTu hist16 (65536);
 
-    double gamma = isRaw ? Color::sRGBGamma : 0;  // usually in ImageSource, but we don't have that here
     ipf.firstAnalysis (baseImg, params, hist16);
 
     // perform transform
@@ -958,7 +1063,7 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         Imagefloat* trImg = new Imagefloat (fw, fh);
         int origFW;
         int origFH;
-        double tscale;
+        double tscale = 0.0;
         getDimensions(origFW, origFH, tscale);
         ipf.transform (baseImg, trImg, 0, 0, 0, 0, fw, fh, origFW * tscale + 0.5, origFH * tscale + 0.5, focalLen, focalLen35mm, focusDist, 0, true); // Raw rotate degree not detectable here
         delete baseImg;
@@ -989,6 +1094,7 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
     int     hlcomprthresh = params.toneCurve.hlcomprthresh;
 
     if (params.toneCurve.autoexp && aeHistogram) {
+        double logDefGain = 0.0;
         ipf.getAutoExp (aeHistogram, aeHistCompression, logDefGain, params.toneCurve.clip, expcomp, bright, contr, black, hlcompr, hlcomprthresh);
     }
 
@@ -1029,13 +1135,13 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
     bool opautili = false;
 
     if(params.colorToning.enabled) {
-        TMatrix wprof = iccStore->workingSpaceMatrix (params.icm.working);
+        TMatrix wprof = ICCStore::getInstance()->workingSpaceMatrix (params.icm.working);
         double wp[3][3] = {
             {wprof[0][0], wprof[0][1], wprof[0][2]},
             {wprof[1][0], wprof[1][1], wprof[1][2]},
             {wprof[2][0], wprof[2][1], wprof[2][2]}
         };
-        TMatrix wiprof = iccStore->workingSpaceInverseMatrix (params.icm.working);
+        TMatrix wiprof = ICCStore::getInstance()->workingSpaceInverseMatrix (params.icm.working);
         double wip[3][3] = {
             {wiprof[0][0], wiprof[0][1], wiprof[0][2]},
             {wiprof[1][0], wiprof[1][1], wiprof[1][2]},
@@ -1184,7 +1290,6 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         LUTf CAMBrightCurveQ;
         float CAMMean;
         int sk;
-        int scale;
         sk = 16;
         int rtt = 0;
         CieImage* cieView = new CieImage (fw, fh);
@@ -1206,9 +1311,9 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 
     // calculate scale
     if (params.coarse.rotate == 90 || params.coarse.rotate == 270) {
-        myscale = scale * thumbImg->width / fh;
+        myscale = scale * thumbImg->getWidth() / fh;
     } else {
-        myscale = scale * thumbImg->height / fh;
+        myscale = scale * thumbImg->getHeight() / fh;
     }
 
     myscale = 1.0 / myscale;
@@ -1238,9 +1343,9 @@ int Thumbnail::getImageWidth (const procparams::ProcParams& params, int rheight,
     int rwidth;
 
     if (params.coarse.rotate == 90 || params.coarse.rotate == 270) {
-        ratio = (float)(thumbImg->height) / (float)(thumbImg->width);
+        ratio = (float)(thumbImg->getHeight()) / (float)(thumbImg->getWidth());
     } else {
-        ratio = (float)(thumbImg->width) / (float)(thumbImg->height);
+        ratio = (float)(thumbImg->getWidth()) / (float)(thumbImg->getHeight());
     }
 
     rwidth = (int)(ratio * (float)rheight);
@@ -1251,8 +1356,8 @@ int Thumbnail::getImageWidth (const procparams::ProcParams& params, int rheight,
 void Thumbnail::getDimensions (int& w, int& h, double& scaleFac)
 {
     if (thumbImg) {
-        w = thumbImg->width;
-        h = thumbImg->height;
+        w = thumbImg->getWidth();
+        h = thumbImg->getHeight();
         scaleFac = scale;
     } else {
         w = 0;
@@ -1272,15 +1377,17 @@ void Thumbnail::getCamWB (double& temp, double& green)
     green = currWB.getGreen ();
 }
 
-void Thumbnail::getAutoWB (double& temp, double& green, double equal)
+void Thumbnail::getAutoWB (double& temp, double& green, double equal, double tempBias)
 {
 
-    if (equal != wbEqual) {
+    if (equal != wbEqual || tempBias != wbTempBias) {
         // compute the values depending on equal
         ColorTemp cTemp;
         wbEqual = equal;
+        wbTempBias = tempBias;
         // compute autoWBTemp and autoWBGreen
         cTemp.mul2temp(redAWBMul, greenAWBMul, blueAWBMul, wbEqual, autoWBTemp, autoWBGreen);
+        autoWBTemp += autoWBTemp * tempBias;
     }
 
     temp = autoWBTemp;
@@ -1314,11 +1421,11 @@ void Thumbnail::getSpotWB (const procparams::ProcParams& params, int xp, int yp,
             points.push_back (Coord2D (j, i));
         }
 
-    int fw = thumbImg->width, fh = thumbImg->height;
+    int fw = thumbImg->getWidth(), fh = thumbImg->getHeight();
 
     if (params.coarse.rotate == 90 || params.coarse.rotate == 270) {
-        fw = thumbImg->height;
-        fh = thumbImg->width;
+        fw = thumbImg->getHeight();
+        fh = thumbImg->getWidth();
     }
 
     ImProcFunctions ipf (&params, false);
@@ -1343,8 +1450,8 @@ void Thumbnail::getSpotWB (const procparams::ProcParams& params, int xp, int yp,
 void Thumbnail::transformPixel (int x, int y, int tran, int& tx, int& ty)
 {
 
-    int W = thumbImg->width;
-    int H = thumbImg->height;
+    int W = thumbImg->getWidth();
+    int H = thumbImg->getHeight();
     int sw = W, sh = H;
 
     if ((tran & TR_ROT) == TR_R90 || (tran & TR_ROT) == TR_R270) {
@@ -1386,13 +1493,13 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
         return nullptr;
     }
 
-    if (thumbImg->width < trim_width) {
+    if (thumbImg->getWidth() < trim_width) {
         return nullptr;
     }
 
     // to utilize the 8 bit color range of the thumbnail we brighten it and apply gamma correction
-    unsigned char* tmpdata = new unsigned char[thumbImg->height * trim_width];
-    int ix = 0, max;
+    unsigned char* tmpdata = new unsigned char[thumbImg->getHeight() * trim_width];
+    int ix = 0;
 
     if (gammaCorrected) {
         // if it's gamma correct (usually a RAW), we have the problem that there is a lot noise etc. that makes the maximum way too high.
@@ -1417,7 +1524,7 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
         }
 
         // Go down till we cut off that many pixels
-        unsigned long cutoff = thumbImg->height * thumbImg->height * 4 * BurnOffPct;
+        unsigned long cutoff = thumbImg->getHeight() * thumbImg->getHeight() * 4 * BurnOffPct;
 
         int max_;
         unsigned long sum = 0;
@@ -1434,8 +1541,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
         if (thumbImg->getType() == sImage8) {
             Image8 *image = static_cast<Image8*>(thumbImg);
 
-            for (int i = 0; i < thumbImg->height; i++)
-                for (int j = (thumbImg->width - trim_width) / 2; j < trim_width + (thumbImg->width - trim_width) / 2; j++) {
+            for (int i = 0; i < thumbImg->getHeight(); i++)
+                for (int j = (thumbImg->getWidth() - trim_width) / 2; j < trim_width + (thumbImg->getWidth() - trim_width) / 2; j++) {
                     unsigned short r_, g_, b_;
                     image->convertTo(image->r(i, j), r_);
                     image->convertTo(image->g(i, j), g_);
@@ -1448,8 +1555,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
         } else if (thumbImg->getType() == sImage16) {
             Image16 *image = static_cast<Image16*>(thumbImg);
 
-            for (int i = 0; i < thumbImg->height; i++)
-                for (int j = (thumbImg->width - trim_width) / 2; j < trim_width + (thumbImg->width - trim_width) / 2; j++) {
+            for (int i = 0; i < thumbImg->getHeight(); i++)
+                for (int j = (thumbImg->getWidth() - trim_width) / 2; j < trim_width + (thumbImg->getWidth() - trim_width) / 2; j++) {
                     unsigned short r_, g_, b_;
                     image->convertTo(image->r(i, j), r_);
                     image->convertTo(image->g(i, j), g_);
@@ -1462,8 +1569,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
         } else if (thumbImg->getType() == sImagefloat) {
             Imagefloat *image = static_cast<Imagefloat*>(thumbImg);
 
-            for (int i = 0; i < thumbImg->height; i++)
-                for (int j = (thumbImg->width - trim_width) / 2; j < trim_width + (thumbImg->width - trim_width) / 2; j++) {
+            for (int i = 0; i < thumbImg->getHeight(); i++)
+                for (int j = (thumbImg->getWidth() - trim_width) / 2; j < trim_width + (thumbImg->getWidth() - trim_width) / 2; j++) {
                     unsigned short r_, g_, b_;
                     image->convertTo(image->r(i, j), r_);
                     image->convertTo(image->g(i, j), g_);
@@ -1476,14 +1583,14 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
         }
     } else {
         // If it's not gamma corrected (usually a JPG) we take the normal maximum
-        max = 0;
+        int max = 0;
 
         if (thumbImg->getType() == sImage8) {
             Image8 *image = static_cast<Image8*>(thumbImg);
             unsigned char max_ = 0;
 
-            for (int row = 0; row < image->height; row++)
-                for (int col = 0; col < image->width; col++) {
+            for (int row = 0; row < image->getHeight(); row++)
+                for (int col = 0; col < image->getWidth(); col++) {
                     if (image->r(row, col) > max_) {
                         max_ = image->r(row, col);
                     }
@@ -1506,8 +1613,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
             scaleForSave = 65535 * 8192 / max;
 
             // Correction and gamma to 8 Bit
-            for (int i = 0; i < image->height; i++)
-                for (int j = (image->width - trim_width) / 2; j < trim_width + (image->width - trim_width) / 2; j++) {
+            for (int i = 0; i < image->getHeight(); i++)
+                for (int j = (image->getWidth() - trim_width) / 2; j < trim_width + (image->getWidth() - trim_width) / 2; j++) {
                     unsigned short rtmp, gtmp, btmp;
                     image->convertTo(image->r(i, j), rtmp);
                     image->convertTo(image->g(i, j), gtmp);
@@ -1521,8 +1628,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
             Image16 *image = static_cast<Image16*>(thumbImg);
             unsigned short max_ = 0;
 
-            for (int row = 0; row < image->height; row++)
-                for (int col = 0; col < image->width; col++) {
+            for (int row = 0; row < image->getHeight(); row++)
+                for (int col = 0; col < image->getWidth(); col++) {
                     if (image->r(row, col) > max_) {
                         max_ = image->r(row, col);
                     }
@@ -1545,8 +1652,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
             scaleForSave = 65535 * 8192 / max;
 
             // Correction and gamma to 8 Bit
-            for (int i = 0; i < image->height; i++)
-                for (int j = (image->width - trim_width) / 2; j < trim_width + (image->width - trim_width) / 2; j++) {
+            for (int i = 0; i < image->getHeight(); i++)
+                for (int j = (image->getWidth() - trim_width) / 2; j < trim_width + (image->getWidth() - trim_width) / 2; j++) {
                     unsigned short rtmp, gtmp, btmp;
                     image->convertTo(image->r(i, j), rtmp);
                     image->convertTo(image->g(i, j), gtmp);
@@ -1560,8 +1667,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
             Imagefloat *image = static_cast<Imagefloat*>(thumbImg);
             float max_ = 0.f;
 
-            for (int row = 0; row < image->height; row++)
-                for (int col = 0; col < image->width; col++) {
+            for (int row = 0; row < image->getHeight(); row++)
+                for (int col = 0; col < image->getWidth(); col++) {
                     if (image->r(row, col) > max_) {
                         max_ = image->r(row, col);
                     }
@@ -1584,8 +1691,8 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
             scaleForSave = 65535 * 8192 / max;
 
             // Correction and gamma to 8 Bit
-            for (int i = 0; i < image->height; i++)
-                for (int j = (image->width - trim_width) / 2; j < trim_width + (image->width - trim_width) / 2; j++) {
+            for (int i = 0; i < image->getHeight(); i++)
+                for (int j = (image->getWidth() - trim_width) / 2; j < trim_width + (image->getWidth() - trim_width) / 2; j++) {
                     unsigned short rtmp, gtmp, btmp;
                     image->convertTo(image->r(i, j), rtmp);
                     image->convertTo(image->g(i, j), gtmp);
@@ -1617,7 +1724,7 @@ unsigned char* Thumbnail::getGrayscaleHistEQ (int trim_width)
         }
 
         if (cdf_min != -1) {
-            hist[i] = (cdf - cdf_min) * 255 / ((thumbImg->height * trim_width) - cdf_min);
+            hist[i] = (cdf - cdf_min) * 255 / ((thumbImg->getHeight() * trim_width) - cdf_min);
         }
     }
 
@@ -1645,8 +1752,8 @@ bool Thumbnail::writeImage (const Glib::ustring& fname, int format)
 
     fwrite (thumbImg->getType(), sizeof (char), strlen(thumbImg->getType()), f);
     fputc ('\n', f);
-    guint32 w = guint32(thumbImg->width);
-    guint32 h = guint32(thumbImg->height);
+    guint32 w = guint32(thumbImg->getWidth());
+    guint32 h = guint32(thumbImg->getHeight());
     fwrite (&w, sizeof (guint32), 1, f);
     fwrite (&h, sizeof (guint32), 1, f);
 
