@@ -664,6 +664,7 @@ public:
             {128, "Sigma 35mm f/1.4 DG HSM"},
             {128, "Sigma 18-35mm f/1.8 DC HSM"},
             {128, "Sigma 50-500mm f/4.5-6.3 APO DG OS HSM"},
+            {128, "Sigma 24-105mm f/4 DG HSM | Art 013"},
             {129, "Tamron Lens (129)"},
             {129, "Tamron 200-400mm f/5.6 LD"},
             {129, "Tamron 70-300mm f/4-5.6 LD"},
@@ -676,11 +677,15 @@ public:
             {142, "Voigtlander 70-300mm f/4.5-5.6"},
             {146, "Voigtlander Macro APO-Lanthar 125mm f/2.5 SL"},
             {194, "Tamron SP AF 17-50mm f/2.8 XR Di II LD Aspherical [IF]"},
+            {202, "Tamron SP AF 70-200mm f/2.8 Di LD [IF] Macro"},
             {203, "Tamron SP 70-200mm f/2.8 Di USD"},
             {204, "Tamron SP 24-70mm f/2.8 Di USD"},
-            {213, "Tamron 16-300mm f/3.5-6.3 Di II PZD"},
+            {212, "Tamron 28-300mm f/3.5-6.3 Di PZD"},
+            {213, "Tamron 16-300mm f/3.5-6.3 Di II PZD Macro"},
             {214, "Tamron SP 150-600mm f/5-6.3 Di USD"},
-            {224, "Tamron SP 90mm f/2.8 Di Macro 1:1 USD"},
+            {215, "Tamron SP 15-30mm f/2.8 Di USD"},
+            {218, "Tamron SP 90mm f/2.8 Di Macro 1:1 USD (F017)"},
+            {224, "Tamron SP 90mm f/2.8 Di Macro 1:1 USD (F004)"},
             {255, "Tamron Lens (255)"},
             {255, "Tamron SP AF 17-50mm f/2.8 XR Di II LD Aspherical"},
             {255, "Tamron AF 18-250mm f/3.5-6.3 XR Di II LD"},
@@ -691,7 +696,7 @@ public:
             {255, "Tamron SP AF 70-200mm f/2.8 Di LD IF Macro"},
             {255, "Tamron SP AF 28-75mm f/2.8 XR Di LD Aspherical IF"},
             {255, "Tamron AF 90-300mm f/4.5-5.6 Telemacro"},
-            {1868, "Sigma MC-11 Adapter"},
+            {1868, "Sigma MC-11 SA-E Mount Converter with not-supported Sigma lens"},
             {2550, "Minolta AF 50mm f/1.7"},
             {2551, "Minolta AF 35-70mm f/4 or Other Lens"},
             {2551, "Sigma UC AF 28-70mm f/3.5-4.5"},
@@ -814,6 +819,7 @@ public:
             {4587, "Tamron AF 70-210mm f/2.8 SP LD"},
             {4812, "Metabones Canon EF Speed Booster Ultra"},
             {6118, "Canon EF Adapter"},
+            {6528, "Sigma 16mm f/2.8 Filtermatic Fisheye"},
             {6553, "E-Mount, T-Mount, Other Lens or no lens"},
             {6553, "Sony E 16mm f/2.8"},
             {6553, "Sony E 18-55mm f/3.5-5.6 OSS"},
@@ -827,6 +833,7 @@ public:
             {6553, "Sony E PZ 16-50mm f/3.5-5.6 OSS"},
             {6553, "Sony FE 35mm f/2.8 ZA"},
             {6553, "Sony FE 24-70mm f/4 ZA OSS"},
+            {6553, "Sony FE 85mm f/1.8"},
             {6553, "Sony E 18-200mm f/3.5-6.3 OSS LE"},
             {6553, "Sony E 20mm f/2.8"},
             {6553, "Sony E 35mm f/1.8 OSS"},
@@ -837,32 +844,42 @@ public:
             {6553, "Sony FE 55mm f/1.8 ZA"},
             {6553, "Sony FE 70-200mm f/4 G OSS"},
             {6553, "Sony FE 16-35mm f/4 ZA OSS"},
+            {6553, "Sony FE 50mm f/2.8 Macro"},
             {6553, "Sony FE 28-70mm f/3.5-5.6 OSS"},
             {6553, "Sony FE 35mm f/1.4 ZA"},
             {6553, "Sony FE 24-240mm f/3.5-6.3 OSS"},
             {6553, "Sony FE 28mm f/2"},
             {6553, "Sony FE PZ 28-135mm f/4 G OSS"},
+            {6553, "Sony FE 100mm f/2.8 STF GM OSS"},
             {6553, "Sony FE 24-70mm f/2.8 GM"},
+            {6553, "Sony FE 50mm f/1.4 ZA"},
             {6553, "Sony FE 85mm f/1.4 GM"},
             {6553, "Sony FE 50mm f/1.8"},
             {6553, "Sony FE 21mm f/2.8 (SEL28F20 + SEL075UWC)"},
             {6553, "Sony FE 16mm f/3.5 Fisheye (SEL28F20 + SEL057FEC)"},
             {6553, "Sony FE 70-300mm f/4.5-5.6 G OSS"},
             {6553, "Sony FE 70-200mm f/2.8 GM OSS"},
+            {6553, "Sony FE 70-200mm f/2.8 GM OSS + 1.4X Teleconverter"},
+            {6553, "Sony FE 70-200mm f/2.8 GM OSS + 2X Teleconverter"},
+            {6553, "Samyang AF 50mm f/1.4 FE"},
+            {6553, "Samyang AF 14mm f/2.8 FE"},
             {6553, "Sigma 19mm f/2.8 [EX] DN"},
             {6553, "Sigma 30mm f/2.8 [EX] DN"},
             {6553, "Sigma 60mm f/2.8 DN"},
-            {6553, "Sigma 30mm f/1.4 DC DN | C"},
+            {6553, "Sigma 30mm f/1.4 DC DN | C 016"},
             {6553, "Tamron 18-200mm f/3.5-6.3 Di III VC"},
-            {6553, "Zeiss Batis 25mm f/2"},
-            {6553, "Zeiss Batis 85mm f/1.8"},
-            {6553, "Zeiss Batis 18mm f/2.8"},
-            {6553, "Zeiss Loxia 21mm f/2.8"},
-            {6553, "Zeiss Loxia 35mm f/2"},
-            {6553, "Zeiss Loxia 50mm f/2"},
+            {6553, "Tokina Firin 20mm f/2 FE MF"},
             {6553, "Zeiss Touit 12mm f/2.8"},
             {6553, "Zeiss Touit 32mm f/1.8"},
             {6553, "Zeiss Touit 50mm f/2.8 Macro"},
+            {6553, "Zeiss Batis 25mm f/2"},
+            {6553, "Zeiss Batis 85mm f/1.8"},
+            {6553, "Zeiss Batis 18mm f/2.8"},
+            {6553, "Zeiss Batis 135mm f/2.8"},
+            {6553, "Zeiss Loxia 50mm f/2"},
+            {6553, "Zeiss Loxia 35mm f/2"},
+            {6553, "Zeiss Loxia 21mm f/2.8"},
+            {6553, "Zeiss Loxia 85mm f/2.4"},
             {6553, "Arax MC 35mm f/2.8 Tilt+Shift"},
             {6553, "Arax MC 80mm f/2.8 Tilt+Shift"},
             {6553, "Zenitar MF 16mm f/2.8 Fisheye M42"},
@@ -870,7 +887,7 @@ public:
             {6553, "Pentacon Auto 135mm f/2.8"},
             {6553, "Pentacon Auto 29mm f/2.8"},
             {6553, "Helios 44-2 58mm f/2.0"},
-            {18688, "Sigma MC-11 Adapter"},
+            {18688, "Sigma MC-11 SA-E Mount Converter with not-supported Sigma lens"},
             {25501, "Minolta AF 50mm f/1.7"},
             {25511, "Minolta AF 35-70mm f/4 or Other Lens"},
             {25511, "Sigma UC AF 28-70mm f/3.5-4.5"},
@@ -993,6 +1010,7 @@ public:
             {45871, "Tamron AF 70-210mm f/2.8 SP LD"},
             {48128, "Metabones Canon EF Speed Booster Ultra"},
             {61184, "Canon EF Adapter"},
+            {65280, "Sigma 16mm f/2.8 Filtermatic Fisheye"},
             {65535, "E-Mount, T-Mount, Other Lens or no lens"},
             {65535, "Sony E 16mm f/2.8"},
             {65535, "Sony E 18-55mm f/3.5-5.6 OSS"},
@@ -1006,6 +1024,7 @@ public:
             {65535, "Sony E PZ 16-50mm f/3.5-5.6 OSS"},
             {65535, "Sony FE 35mm f/2.8 ZA"},
             {65535, "Sony FE 24-70mm f/4 ZA OSS"},
+            {65535, "Sony FE 85mm f/1.8"},
             {65535, "Sony E 18-200mm f/3.5-6.3 OSS LE"},
             {65535, "Sony E 20mm f/2.8"},
             {65535, "Sony E 35mm f/1.8 OSS"},
@@ -1016,56 +1035,66 @@ public:
             {65535, "Sony FE 55mm f/1.8 ZA"},
             {65535, "Sony FE 70-200mm f/4 G OSS"},
             {65535, "Sony FE 16-35mm f/4 ZA OSS"},
+            {65535, "Sony FE 50mm f/2.8 Macro"},
             {65535, "Sony FE 28-70mm f/3.5-5.6 OSS"},
             {65535, "Sony FE 35mm f/1.4 ZA"},
             {65535, "Sony FE 24-240mm f/3.5-6.3 OSS"},
             {65535, "Sony FE 28mm f/2"},
             {65535, "Sony FE PZ 28-135mm f/4 G OSS"},
+            {65535, "Sony FE 100mm f/2.8 STF GM OSS"},
             {65535, "Sony FE 24-70mm f/2.8 GM"},
+            {65535, "Sony FE 50mm f/1.4 ZA"},
             {65535, "Sony FE 85mm f/1.4 GM"},
             {65535, "Sony FE 50mm f/1.8"},
             {65535, "Sony FE 21mm f/2.8 (SEL28F20 + SEL075UWC)"},
             {65535, "Sony FE 16mm f/3.5 Fisheye (SEL28F20 + SEL057FEC)"},
             {65535, "Sony FE 70-300mm f/4.5-5.6 G OSS"},
             {65535, "Sony FE 70-200mm f/2.8 GM OSS"},
+            {65535, "Sony FE 70-200mm f/2.8 GM OSS + 1.4X Teleconverter"},
+            {65535, "Sony FE 70-200mm f/2.8 GM OSS + 2X Teleconverter"},
+            {65535, "Samyang AF 50mm f/1.4 FE"},
+            {65535, "Samyang AF 14mm f/2.8 FE"},
             {65535, "Sigma 19mm f/2.8 [EX] DN"},
             {65535, "Sigma 30mm f/2.8 [EX] DN"},
             {65535, "Sigma 60mm f/2.8 DN"},
-            {65535, "Sigma 30mm f/1.4 DC DN | C"},
+            {65535, "Sigma 30mm f/1.4 DC DN | C 016"},
             {65535, "Tamron 18-200mm f/3.5-6.3 Di III VC"},
-            {65535, "Zeiss Batis 25mm f/2"},
-            {65535, "Zeiss Batis 85mm f/1.8"},
-            {65535, "Zeiss Batis 18mm f/2.8"},
-            {65535, "Zeiss Loxia 21mm f/2.8"},
-            {65535, "Zeiss Loxia 35mm f/2"},
-            {65535, "Zeiss Loxia 50mm f/2"},
+            {65535, "Tokina Firin 20mm f/2 FE MF"},
             {65535, "Zeiss Touit 12mm f/2.8"},
             {65535, "Zeiss Touit 32mm f/1.8"},
             {65535, "Zeiss Touit 50mm f/2.8 Macro"},
+            {65535, "Zeiss Batis 25mm f/2"},
+            {65535, "Zeiss Batis 85mm f/1.8"},
+            {65535, "Zeiss Batis 18mm f/2.8"},
+            {65535, "Zeiss Batis 135mm f/2.8"},
+            {65535, "Zeiss Loxia 50mm f/2"},
+            {65535, "Zeiss Loxia 35mm f/2"},
+            {65535, "Zeiss Loxia 21mm f/2.8"},
+            {65535, "Zeiss Loxia 85mm f/2.4"},
             {65535, "Arax MC 35mm f/2.8 Tilt+Shift"},
             {65535, "Arax MC 80mm f/2.8 Tilt+Shift"},
             {65535, "Zenitar MF 16mm f/2.8 Fisheye M42"},
             {65535, "Samyang 500mm Mirror f/8.0"},
             {65535, "Pentacon Auto 135mm f/2.8"},
             {65535, "Pentacon Auto 29mm f/2.8"},
-            {65535, "Helios 44-2 58mm f/2.0"}
+            {65535, "Helios 44-2 58mm f/2.0"},
         };
     }
 
     virtual std::string toString (Tag* t)
     {
         int lensID = t->toInt();
-        Tag *lensInfoTag = t->getParent()->getRoot()->findTag("LensInfo");
-        Tag *apertureTag = t->getParent()->getRoot()->findTag("MaxApertureValue");
-        Tag *focalLengthTag = t->getParent()->getRoot()->findTag("FocalLength");
+        Tag *lensInfoTag = t->getParent()->getRoot()->findTag ("LensInfo");
+        Tag *apertureTag = t->getParent()->getRoot()->findTag ("MaxApertureValue");
+        Tag *focalLengthTag = t->getParent()->getRoot()->findTag ("FocalLength");
         double maxApertureAtFocal = 0.;
         double focalLength = 0.;
 
-        if( apertureTag ) {
-            maxApertureAtFocal = pow(2.0, apertureTag->toDouble() / 2.0);
+        if ( apertureTag ) {
+            maxApertureAtFocal = pow (2.0, apertureTag->toDouble() / 2.0);
         }
 
-        if( focalLengthTag ) {
+        if ( focalLengthTag ) {
             focalLength = focalLengthTag->toDouble();
         }
 
@@ -1075,9 +1104,9 @@ public:
             liArray = lensInfoTag->toDoubleArray();
         }
 
-        std::string retval = guess( lensID, focalLength, maxApertureAtFocal, liArray);
+        std::string retval = guess ( lensID, focalLength, maxApertureAtFocal, liArray);
 
-        if(liArray) {
+        if (liArray) {
             delete [] liArray;
         }
 
@@ -1091,87 +1120,104 @@ class SALensID2Interpreter : public IntLensInterpreter< int >
 public:
     SALensID2Interpreter ()
     {
-        choices.insert(p_t(0, "Unknown E-mount lens or other lens"));
-        choices.insert(p_t(1, "Sony LA-EA1 Adapter"));
-        choices.insert(p_t(2, "Sony LA-EA2 Adapter"));
-        choices.insert(p_t(3, "Sony LA-EA3 Adapter"));
-        choices.insert(p_t(6, "Sony LA-EA4 Adapter"));
-        choices.insert(p_t(44, "Metabones Canon EF Smart Adapter"));
-        choices.insert(p_t(78, "Metabones Canon EF Smart Adapter Mark III or Other Adapter"));
-        choices.insert(p_t(234, "Metabones Canon EF Smart Adapter Mark IV"));
-        choices.insert(p_t(239, "Metabones Canon EF Speed Booster"));
-        choices.insert(p_t(32784, "Sony E 16mm f/2.8"));
-        choices.insert(p_t(32785, "Sony E 18-55mm f/3.5-5.6 OSS"));
-        choices.insert(p_t(32786, "Sony E 55-210mm f/4.5-6.3 OSS"));
-        choices.insert(p_t(32787, "Sony E 18-200mm f/3.5-6.3 OSS"));
-        choices.insert(p_t(32788, "Sony E 30mm f/3.5 Macro"));
-        choices.insert(p_t(32789, "Sony E 24mm f/1.8 ZA"));
-        choices.insert(p_t(32790, "Sony E 50mm f/1.8 OSS"));
-        choices.insert(p_t(32791, "Sony E 16-70mm f/4 ZA OSS"));
-        choices.insert(p_t(32792, "Sony E 10-18mm f/4 OSS"));
-        choices.insert(p_t(32793, "Sony E PZ 16-50mm f/3.5-5.6 OSS"));
-        choices.insert(p_t(32794, "Sony FE 35mm f/2.8 ZA"));
-        choices.insert(p_t(32795, "Sony FE 24-70mm f/4 ZA OSS"));
-        choices.insert(p_t(32797, "Sony E 18-200mm f/3.5-6.3 OSS LE"));
-        choices.insert(p_t(32798, "Sony E 20mm f/2.8"));
-        choices.insert(p_t(32799, "Sony E 35mm f/1.8 OSS"));
-        choices.insert(p_t(32800, "Sony E PZ 18-105mm f/4 G OSS"));
-        choices.insert(p_t(32802, "Sony FE 90mm f/2.8 Macro G OSS"));
-        choices.insert(p_t(32803, "Sony E 18-50mm f/4-5.6"));
-        choices.insert(p_t(32807, "Sony E PZ 18-200mm f/3.5-6.3 OSS"));
-        choices.insert(p_t(32808, "Sony FE 55mm f/1.8 ZA"));
-        choices.insert(p_t(32810, "Sony FE 70-200mm f/4 G OSS"));
-        choices.insert(p_t(32811, "Sony FE 16-35mm f/4 ZA OSS"));
-        choices.insert(p_t(32813, "Sony FE 28-70mm f/3.5-5.6 OSS"));
-        choices.insert(p_t(32814, "Sony FE 35mm f/1.4 ZA"));
-        choices.insert(p_t(32815, "Sony FE 24-240mm f/3.5-6.3 OSS"));
-        choices.insert(p_t(32816, "Sony FE 28mm f/2"));
-        choices.insert(p_t(32817, "Sony FE PZ 28-135mm f/4 G OSS"));
-        choices.insert(p_t(32821, "Sony FE 24-70mm f/2.8 GM"));
-        choices.insert(p_t(32823, "Sony FE 85mm f/1.4 GM"));
-        choices.insert(p_t(32824, "Sony FE 50mm f/1.8"));
-        choices.insert(p_t(32826, "Sony FE 21mm f/2.8 (SEL28F20 + SEL075UWC)"));
-        choices.insert(p_t(32827, "Sony FE 16mm f/3.5 Fisheye (SEL28F20 + SEL057FEC)"));
-        choices.insert(p_t(32828, "Sony FE 70-300mm f/4.5-5.6 G OSS"));
-        choices.insert(p_t(32830, "Sony FE 70-200mm f/2.8 GM OSS"));
-        choices.insert(p_t(49201, "Zeiss Touit 12mm f/2.8"));
-        choices.insert(p_t(49202, "Zeiss Touit 32mm f/1.8"));
-        choices.insert(p_t(49203, "Zeiss Touit 50mm f/2.8 Macro"));
-        choices.insert(p_t(49216, "Zeiss Batis 25mm f/2"));
-        choices.insert(p_t(49217, "Zeiss Batis 85mm f/1.8"));
-        choices.insert(p_t(49218, "Zeiss Batis 18mm f/2.8"));
-        choices.insert(p_t(49232, "Zeiss Loxia 50mm f/2"));
-        choices.insert(p_t(49233, "Zeiss Loxia 35mm f/2"));
-        choices.insert(p_t(49234, "Zeiss Loxia 21mm f/2.8"));
-        choices.insert(p_t(50480, "Sigma 30mm f/1.4 DC DN | C 016"));
-        choices.insert(p_t(50481, "Sigma 50mm f/1.4 DG HSM | A 014 + MC-11"));
-        choices.insert(p_t(50482, "Sigma 18-300mm f/3.5-6.3 DC MACRO OS HSM | C 014 + MC-11"));
-        choices.insert(p_t(50483, "Sigma 18-35mm f/1.8 DC HSM | A 013 + MC-11"));
-        choices.insert(p_t(50484, "Sigma 24-35mm f/2 DG HSM | A 015 + MC-11"));
-        choices.insert(p_t(50486, "Sigma 150-600mm f/5-6.3 DG OS HSM | C 015 + MC-11"));
-        choices.insert(p_t(50487, "Sigma 20mm f/1.4 DG HSM | A 015 + MC-11"));
-        choices.insert(p_t(50488, "Sigma 35mm f/1.4 DG HSM | A 012 + MC-11"));
-        choices.insert(p_t(50489, "Sigma 150-600mm f/5-6.3 DG OS HSM | S 014 + MC-11"));
-        choices.insert(p_t(50490, "Sigma 120-300mm f/2.8 DG OS HSM | S 013 + MC-11"));
-        choices.insert(p_t(50492, "Sigma 24-105mm f/4 DG OS HSM | A 013 + MC-11"));
-        choices.insert(p_t(50493, "Sigma 17-70mm f/2.8-4 DC MACRO OS HSM | C 013 + MC-11"));
-        choices.insert(p_t(50495, "Sigma 50-100mm f/1.8 DC HSM | A 016 + MC-11"));
+        choices.insert (p_t (0, "Unknown E-mount lens or other lens"));
+        choices.insert (p_t (1, "Sony LA-EA1 Adapter"));
+        choices.insert (p_t (2, "Sony LA-EA2 Adapter"));
+        choices.insert (p_t (3, "Sony LA-EA3 Adapter"));
+        choices.insert (p_t (6, "Sony LA-EA4 Adapter"));
+        choices.insert (p_t (44, "Metabones Canon EF Smart Adapter"));
+        choices.insert (p_t (78, "Metabones Canon EF Smart Adapter Mark III or Other Adapter"));
+        choices.insert (p_t (234, "Metabones Canon EF Smart Adapter Mark IV"));
+        choices.insert (p_t (239, "Metabones Canon EF Speed Booster"));
+        choices.insert (p_t (32784, "Sony E 16mm f/2.8"));
+        choices.insert (p_t (32785, "Sony E 18-55mm f/3.5-5.6 OSS"));
+        choices.insert (p_t (32786, "Sony E 55-210mm f/4.5-6.3 OSS"));
+        choices.insert (p_t (32787, "Sony E 18-200mm f/3.5-6.3 OSS"));
+        choices.insert (p_t (32788, "Sony E 30mm f/3.5 Macro"));
+        choices.insert (p_t (32789, "Sony E 24mm f/1.8 ZA or Samyang AF 50mm f/1.4 FE"));
+        choices.insert (p_t (32789, "Samyang AF 50mm f/1.4 FE"));
+        choices.insert (p_t (32790, "Sony E 50mm f/1.8 OSS or Samyang AF 14mm f/2.8 FE"));
+        choices.insert (p_t (32790, "Samyang AF 14mm f/2.8 FE"));
+        choices.insert (p_t (32791, "Sony E 16-70mm f/4 ZA OSS"));
+        choices.insert (p_t (32792, "Sony E 10-18mm f/4 OSS"));
+        choices.insert (p_t (32793, "Sony E PZ 16-50mm f/3.5-5.6 OSS"));
+        choices.insert (p_t (32794, "Sony FE 35mm f/2.8 ZA"));
+        choices.insert (p_t (32795, "Sony FE 24-70mm f/4 ZA OSS"));
+        choices.insert (p_t (32796, "Sony FE 85mm f/1.8"));
+        choices.insert (p_t (32797, "Sony E 18-200mm f/3.5-6.3 OSS LE"));
+        choices.insert (p_t (32798, "Sony E 20mm f/2.8"));
+        choices.insert (p_t (32799, "Sony E 35mm f/1.8 OSS"));
+        choices.insert (p_t (32800, "Sony E PZ 18-105mm f/4 G OSS"));
+        choices.insert (p_t (32802, "Sony FE 90mm f/2.8 Macro G OSS"));
+        choices.insert (p_t (32803, "Sony E 18-50mm f/4-5.6"));
+        choices.insert (p_t (32807, "Sony E PZ 18-200mm f/3.5-6.3 OSS"));
+        choices.insert (p_t (32808, "Sony FE 55mm f/1.8 ZA"));
+        choices.insert (p_t (32810, "Sony FE 70-200mm f/4 G OSS"));
+        choices.insert (p_t (32811, "Sony FE 16-35mm f/4 ZA OSS"));
+        choices.insert (p_t (32812, "Sony FE 50mm f/2.8 Macro"));
+        choices.insert (p_t (32813, "Sony FE 28-70mm f/3.5-5.6 OSS"));
+        choices.insert (p_t (32814, "Sony FE 35mm f/1.4 ZA"));
+        choices.insert (p_t (32815, "Sony FE 24-240mm f/3.5-6.3 OSS"));
+        choices.insert (p_t (32816, "Sony FE 28mm f/2"));
+        choices.insert (p_t (32817, "Sony FE PZ 28-135mm f/4 G OSS"));
+        choices.insert (p_t (32819, "Sony FE 100mm f/2.8 STF GM OSS"));
+        choices.insert (p_t (32821, "Sony FE 24-70mm f/2.8 GM"));
+        choices.insert (p_t (32822, "Sony FE 50mm f/1.4 ZA"));
+        choices.insert (p_t (32823, "Sony FE 85mm f/1.4 GM"));
+        choices.insert (p_t (32824, "Sony FE 50mm f/1.8"));
+        choices.insert (p_t (32826, "Sony FE 21mm f/2.8 (SEL28F20 + SEL075UWC)"));
+        choices.insert (p_t (32827, "Sony FE 16mm f/3.5 Fisheye (SEL28F20 + SEL057FEC)"));
+        choices.insert (p_t (32828, "Sony FE 70-300mm f/4.5-5.6 G OSS"));
+        choices.insert (p_t (32830, "Sony FE 70-200mm f/2.8 GM OSS"));
+        choices.insert (p_t (33002, "Sigma 85mm f/1.4 DG HSM | A 016 (+ Metabones Ver.50)"));
+        choices.insert (p_t (33072, "Sony FE 70-200mm f/2.8 GM OSS + 1.4X Teleconverter"));
+        choices.insert (p_t (33073, "Sony FE 70-200mm f/2.8 GM OSS + 2X Teleconverter"));
+        choices.insert (p_t (33076, "Sony FE 100mm f/2.8 STF GM OSS (macro mode)"));
+        choices.insert (p_t (49201, "Zeiss Touit 12mm f/2.8"));
+        choices.insert (p_t (49202, "Zeiss Touit 32mm f/1.8"));
+        choices.insert (p_t (49203, "Zeiss Touit 50mm f/2.8 Macro"));
+        choices.insert (p_t (49216, "Zeiss Batis 25mm f/2"));
+        choices.insert (p_t (49217, "Zeiss Batis 85mm f/1.8"));
+        choices.insert (p_t (49218, "Zeiss Batis 18mm f/2.8"));
+        choices.insert (p_t (49219, "Zeiss Batis 135mm f/2.8"));
+        choices.insert (p_t (49232, "Zeiss Loxia 50mm f/2"));
+        choices.insert (p_t (49233, "Zeiss Loxia 35mm f/2"));
+        choices.insert (p_t (49234, "Zeiss Loxia 21mm f/2.8"));
+        choices.insert (p_t (49235, "Zeiss Loxia 85mm f/2.4"));
+        choices.insert (p_t (50480, "Sigma 30mm f/1.4 DC DN | C 016"));
+        choices.insert (p_t (50481, "Sigma 50mm f/1.4 DG HSM | A 014 + MC-11"));
+        choices.insert (p_t (50482, "Sigma 18-300mm f/3.5-6.3 DC MACRO OS HSM | C 014 + MC-11"));
+        choices.insert (p_t (50483, "Sigma 18-35mm f/1.8 DC HSM | A 013 + MC-11"));
+        choices.insert (p_t (50484, "Sigma 24-35mm f/2 DG HSM | A 015 + MC-11"));
+        choices.insert (p_t (50486, "Sigma 150-600mm f/5-6.3 DG OS HSM | C 015 + MC-11"));
+        choices.insert (p_t (50487, "Sigma 20mm f/1.4 DG HSM | A 015 + MC-11"));
+        choices.insert (p_t (50488, "Sigma 35mm f/1.4 DG HSM | A 012 + MC-11"));
+        choices.insert (p_t (50489, "Sigma 150-600mm f/5-6.3 DG OS HSM | S 014 + MC-11"));
+        choices.insert (p_t (50490, "Sigma 120-300mm f/2.8 DG OS HSM | S 013 + MC-11"));
+        choices.insert (p_t (50492, "Sigma 24-105mm f/4 DG OS HSM | A 013 + MC-11"));
+        choices.insert (p_t (50493, "Sigma 17-70mm f/2.8-4 DC MACRO OS HSM | C 013 + MC-11"));
+        choices.insert (p_t (50495, "Sigma 50-100mm f/1.8 DC HSM | A 016 + MC-11"));
+        choices.insert (p_t (50992, "Voigtlander SUPER WIDE-HELIAR 15mm f/4.5 III"));
+        choices.insert (p_t (50993, "Voigtlander HELIAR-HYPER WIDE 10mm f/5.6"));
+        choices.insert (p_t (50994, "Voigtlander ULTRA WIDE-HELIAR 12mm f/5.6 III"));
+        choices.insert (p_t (50996, "Voigtlander NOKTON 40mm f/1.2 Aspherical"));
+        choices.insert (p_t (51505, "Samyang AF 14mm f/2.8 FE"));
     }
 
     virtual std::string toString (Tag* t)
     {
         int lensID = t->toInt();
-        Tag *lensInfoTag = t->getParent()->getRoot()->findTag("LensInfo");
-        Tag *apertureTag = t->getParent()->getRoot()->findTag("MaxApertureValue");
-        Tag *focalLengthTag = t->getParent()->getRoot()->findTag("FocalLength");
+        Tag *lensInfoTag = t->getParent()->getRoot()->findTag ("LensInfo");
+        Tag *apertureTag = t->getParent()->getRoot()->findTag ("MaxApertureValue");
+        Tag *focalLengthTag = t->getParent()->getRoot()->findTag ("FocalLength");
         double maxApertureAtFocal = 0.;
         double focalLength = 0.;
 
-        if( apertureTag ) {
-            maxApertureAtFocal = pow(2.0, apertureTag->toDouble() / 2.0);
+        if ( apertureTag ) {
+            maxApertureAtFocal = pow (2.0, apertureTag->toDouble() / 2.0);
         }
 
-        if( focalLengthTag ) {
+        if ( focalLengthTag ) {
             focalLength = focalLengthTag->toDouble();
         }
 
@@ -1181,9 +1227,9 @@ public:
             liArray = lensInfoTag->toDoubleArray();
         }
 
-        std::string retval = guess( lensID, focalLength, maxApertureAtFocal, liArray);
+        std::string retval = guess ( lensID, focalLength, maxApertureAtFocal, liArray);
 
-        if(liArray) {
+        if (liArray) {
             delete [] liArray;
         }
 
@@ -1956,7 +2002,7 @@ public:
     {
         double a = t->toDouble();
 
-        if(a > 0) {
+        if (a > 0) {
             char buffer[32];
             sprintf (buffer, "%.4f", a);
             return buffer;
@@ -1977,8 +2023,8 @@ public:
         }
 
         // Decode the value
-        if(a > 0) {
-            return pow(2., 6. - (double(a) / 8.));
+        if (a > 0) {
+            return pow (2., 6. - (double (a) / 8.));
         } else {
             return 0.;
         }
@@ -1999,8 +2045,8 @@ public:
         }
 
         // Decode the value
-        if(a) {
-            return int(powf(2.f, 6.f - (float(a) / 8.f)) + 0.5f);
+        if (a) {
+            return int (powf (2.f, 6.f - (float (a) / 8.f)) + 0.5f);
         } else {
             return 0;
         }
@@ -2014,9 +2060,9 @@ public:
     SAFNumberInterpreter () {}
     virtual std::string toString (Tag* t)
     {
-        double a = double(t->toDouble());
+        double a = double (t->toDouble());
 
-        if(a) {
+        if (a) {
             char buffer[32];
             sprintf (buffer, "%.1f", a / 100. );
             return buffer;
@@ -2037,8 +2083,8 @@ public:
         }
 
         // Decode the value
-        if(a > 0) {
-            return pow(2., (double(a) / 8. - 1.) / 2.);
+        if (a > 0) {
+            return pow (2., (double (a) / 8. - 1.) / 2.);
         } else {
             return 0.;
         }
@@ -2059,8 +2105,8 @@ public:
         }
 
         // Decode the value
-        if(a) {
-            return int(powf(2.f, (float(a) / 8.f - 1.f) / 2.f) + 0.5f);
+        if (a) {
+            return int (powf (2.f, (float (a) / 8.f - 1.f) / 2.f) + 0.5f);
         } else {
             return 0;
         }
@@ -2076,7 +2122,7 @@ public:
     {
         int a = t->toInt();
 
-        if(a) {
+        if (a) {
             char buffer[32];
             sprintf (buffer, "%d", a );
             return buffer;
@@ -2100,8 +2146,8 @@ public:
         }
 
         // Decode the value
-        if(a && a != 254) { // 254 = 'Auto' for CameraSettings3, but we might say the same for CameraSettings & CameraSettings2 (?)
-            return int(expf((double(a) / 8.f - 6.f) * logf(2.f)) * 100.f + 0.5f);
+        if (a && a != 254) { // 254 = 'Auto' for CameraSettings3, but we might say the same for CameraSettings & CameraSettings2 (?)
+            return int (expf ((double (a) / 8.f - 6.f) * logf (2.f)) * 100.f + 0.5f);
         } else {
             return 0;
         }
@@ -2125,7 +2171,7 @@ public:
         // Get the value
         int a = t->getValue()[ofs];
         // Decode the value
-        return (double(a) - 128.) / 24.;
+        return (double (a) - 128.) / 24.;
     }
 };
 SAExposureCompSetInterpreter saExposureCompSetInterpreter;
