@@ -24,14 +24,6 @@
 #include "soundman.h"
 #include "rtimage.h"
 
-int processLoadedBatchQueueUIThread (void* data)
-{
-
-    BatchQueue* bq = static_cast<BatchQueue*>(data);
-    bq->resizeLoadedQueue();
-    return 0;
-}
-
 static Glib::ustring makeFolderLabel(Glib::ustring path)
 {
     if (!Glib::file_test (path, Glib::FILE_TEST_IS_DIR)) {
@@ -111,10 +103,13 @@ BatchQueuePanel::BatchQueuePanel (FileCatalog* aFileCatalog)
     outdirFolder = Gtk::manage (new MyFileChooserButton (M("PREFERENCES_OUTDIRFOLDER"), Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER));
     hb3->pack_start (*outdirFolder);
     outdirFolder->signal_current_folder_changed().connect (sigc::mem_fun(*this, &BatchQueuePanel::pathFolderChanged));
+    outdirFolder->signal_selection_changed().connect (sigc::mem_fun(*this, &BatchQueuePanel::pathFolderChanged));
     outdirFolder->set_tooltip_markup (M("PREFERENCES_OUTDIRFOLDERHINT"));
 
     if (Glib::file_test (options.savePathFolder, Glib::FILE_TEST_IS_DIR)) {
         outdirFolder->set_current_folder (options.savePathFolder);
+    } else {
+        outdirFolder->set_current_folder (Glib::get_home_dir());
     }
 
     outdirFolderButton = 0;
@@ -183,11 +178,22 @@ BatchQueuePanel::BatchQueuePanel (FileCatalog* aFileCatalog)
 
     show_all ();
 
-    if (batchQueue->loadBatchQueue ()) {
-        g_idle_add_full (G_PRIORITY_LOW, processLoadedBatchQueueUIThread, batchQueue, nullptr);
+    if (batchQueue->loadBatchQueue()) {
+        const auto func = [](gpointer data) -> gboolean {
+            static_cast<BatchQueue*>(data)->resizeLoadedQueue();
+
+            return FALSE;
+        };
+
+        idle_register.add(func, batchQueue, G_PRIORITY_LOW);
     }
 }
 
+BatchQueuePanel::~BatchQueuePanel()
+{
+    idle_register.destroy();
+}
+
 void BatchQueuePanel::init (RTWindow *parent)
 {
     this->parent = parent;
