@@ -19,6 +19,7 @@
 #include "cachemanager.h"
 
 #include <memory>
+#include <iostream>
 
 #include <glib/gstdio.h>
 #include <giomm.h>
@@ -35,8 +36,8 @@
 namespace
 {
 
-constexpr auto cacheDirMode = 511;
-constexpr auto cacheDirs = { "profiles", "images", "aehistograms", "embprofiles", "data" };
+constexpr int cacheDirMode = 0777;
+constexpr const char* cacheDirs[] = { "profiles", "images", "aehistograms", "embprofiles", "data" };
 
 }
 
