@@ -134,7 +134,7 @@ FileBrowser::FileBrowser ()
     fbih->destroyed = false;
     fbih->pending = 0;
 
-    profileStore.addListener(this);
+    ProfileStore::getInstance()->addListener(this);
 
     int p = 0;
     pmenu = new Gtk::Menu ();
@@ -340,7 +340,7 @@ FileBrowser::FileBrowser ()
         p++;
         submenuProfileOperations->attach (*Gtk::manage(applypartprof = new Gtk::MenuItem (M("FILEBROWSER_APPLYPROFILE_PARTIAL"))), 0, 1, p, p + 1);
         p++;
-        submenuProfileOperations->attach (*Gtk::manage(execcustprof = new Gtk::MenuItem (M("FILEBROWSER_EXEC_CPB"))), 0, 1, p, p + 1);
+        submenuProfileOperations->attach (*Gtk::manage(resetdefaultprof = new Gtk::MenuItem (M("FILEBROWSER_RESETDEFAULTPROFILE"))), 0, 1, p, p + 1);
         p++;
         submenuProfileOperations->attach (*Gtk::manage(clearprof = new Gtk::MenuItem (M("FILEBROWSER_CLEARPROFILE"))), 0, 1, p, p + 1);
         p++;
@@ -358,7 +358,7 @@ FileBrowser::FileBrowser ()
         p++;
         pmenu->attach (*Gtk::manage(applypartprof = new Gtk::MenuItem (M("FILEBROWSER_APPLYPROFILE_PARTIAL"))), 0, 1, p, p + 1);
         p++;
-        pmenu->attach (*Gtk::manage(execcustprof = new Gtk::MenuItem (M("FILEBROWSER_EXEC_CPB"))), 0, 1, p, p + 1);
+        pmenu->attach (*Gtk::manage(resetdefaultprof = new Gtk::MenuItem (M("FILEBROWSER_RESETDEFAULTPROFILE"))), 0, 1, p, p + 1);
         p++;
         pmenu->attach (*Gtk::manage(clearprof = new Gtk::MenuItem (M("FILEBROWSER_CLEARPROFILE"))), 0, 1, p, p + 1);
         p++;
@@ -375,7 +375,6 @@ FileBrowser::FileBrowser ()
     pmenu->attach (*Gtk::manage(new Gtk::SeparatorMenuItem ()), 0, 1, p, p + 1);
     p++;
     pmenu->attach (*Gtk::manage(cachemenu = new Gtk::MenuItem (M("FILEBROWSER_CACHE"))), 0, 1, p, p + 1);
-    p++;
 
     pmenu->show_all ();
 
@@ -389,6 +388,7 @@ FileBrowser::FileBrowser ()
     untrash->add_accelerator ("activate", pmenu->get_accel_group(), GDK_KEY_Delete, Gdk::SHIFT_MASK, Gtk::ACCEL_VISIBLE);
     open->add_accelerator ("activate", pmenu->get_accel_group(), GDK_KEY_Return, (Gdk::ModifierType)0, Gtk::ACCEL_VISIBLE);
     develop->add_accelerator ("activate", pmenu->get_accel_group(), GDK_KEY_B, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+    developfast->add_accelerator ("activate", pmenu->get_accel_group(), GDK_KEY_B, Gdk::CONTROL_MASK | Gdk::SHIFT_MASK, Gtk::ACCEL_VISIBLE);
     copyprof->add_accelerator ("activate", pmenu->get_accel_group(), GDK_KEY_C, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     pasteprof->add_accelerator ("activate", pmenu->get_accel_group(), GDK_KEY_V, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     partpasteprof->add_accelerator ("activate", pmenu->get_accel_group(), GDK_KEY_V, Gdk::CONTROL_MASK | Gdk::SHIFT_MASK, Gtk::ACCEL_VISIBLE);
@@ -404,7 +404,7 @@ FileBrowser::FileBrowser ()
         colorlabel[i]->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), colorlabel[i]));
     }
 
-    for (int i = 0; i < mMenuExtProgs.size(); i++) {
+    for (size_t i = 0; i < mMenuExtProgs.size(); i++) {
         amiExtProg[i]->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), amiExtProg[i]));
     }
 
@@ -427,7 +427,7 @@ FileBrowser::FileBrowser ()
     partpasteprof->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), partpasteprof));
     applyprof->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), applyprof));
     applypartprof->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), applypartprof));
-    execcustprof->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), execcustprof));
+    resetdefaultprof->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), resetdefaultprof));
     clearprof->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), clearprof));
     cachemenu->signal_activate().connect (sigc::bind(sigc::mem_fun(*this, &FileBrowser::menuItemActivated), cachemenu));
 
@@ -455,7 +455,9 @@ FileBrowser::FileBrowser ()
 
 FileBrowser::~FileBrowser ()
 {
-    profileStore.removeListener(this);
+    idle_register.destroy();
+
+    ProfileStore::getInstance()->removeListener(this);
     delete pmenu;
     delete pmenuColorLabels;
     delete[] amiExtProg;
@@ -541,51 +543,48 @@ void FileBrowser::doubleClicked (ThumbBrowserEntryBase* entry)
     }
 }
 
-struct addparams {
-    FileBrowserIdleHelper* fbih;
-    FileBrowserEntry* entry;
-};
-
-int AddEntryUIThread (void* data)
-{
-
-    addparams* ap = static_cast<addparams*>(data);
-    FileBrowserIdleHelper* fbih = ap->fbih;
-
-    if (fbih->destroyed) {
-        if (fbih->pending == 1) {
-            delete fbih;
-        } else {
-            fbih->pending--;
-        }
-
-        delete ap->entry;
-        delete ap;
-
-        return 0;
-    }
-
-    ap->fbih->fbrowser->addEntry_ (ap->entry);
-    delete ap;
-    fbih->pending--;
-
-    return 0;
-}
-
 void FileBrowser::addEntry (FileBrowserEntry* entry)
 {
+    struct addparams {
+        FileBrowserIdleHelper* fbih;
+        FileBrowserEntry* entry;
+    };
 
     fbih->pending++;
     entry->setParent (this);
-    addparams* ap = new addparams;
+    addparams* const ap = new addparams;
     ap->fbih = fbih;
     ap->entry = entry;
-    g_idle_add (AddEntryUIThread, ap);
+
+    const auto func = [](gpointer data) -> gboolean {
+        addparams* const ap = static_cast<addparams*>(data);
+        FileBrowserIdleHelper* fbih = ap->fbih;
+
+        if (fbih->destroyed) {
+            if (fbih->pending == 1) {
+                delete fbih;
+            } else {
+                fbih->pending--;
+            }
+
+            delete ap->entry;
+            delete ap;
+
+            return 0;
+        }
+
+        ap->fbih->fbrowser->addEntry_ (ap->entry);
+        delete ap;
+        fbih->pending--;
+
+        return FALSE;
+    };
+
+    idle_register.add(func, ap);
 }
 
 void FileBrowser::addEntry_ (FileBrowserEntry* entry)
 {
-    GThreadLock lock; // All GUI acces from idle_add callbacks or separate thread HAVE to be protected
     entry->selected = false;
     entry->drawable = false;
     entry->framed = editedFiles.find (entry->filename) != editedFiles.end();
@@ -730,14 +729,14 @@ void FileBrowser::menuItemActivated (Gtk::MenuItem* m)
             return;
         }
 
-    for (int j = 0; j < mMenuExtProgs.size(); j++) {
+    for (size_t j = 0; j < mMenuExtProgs.size(); j++) {
         if (m == amiExtProg[j]) {
             const auto pAct = mMenuExtProgs[m->get_label()];
 
             // Build vector of all file names
             std::vector<Glib::ustring> selFileNames;
 
-            for (int i = 0; i < mselected.size(); i++) {
+            for (size_t i = 0; i < mselected.size(); i++) {
                 Glib::ustring fn = mselected[i]->thumbnail->getFileName();
 
                 // Maybe batch processed version
@@ -768,6 +767,12 @@ void FileBrowser::menuItemActivated (Gtk::MenuItem* m)
     else if (m == develop) {
         tbl->developRequested (mselected, false);
     } else if (m == developfast) {
+        if (exportPanel) {
+            // force saving export panel settings
+            exportPanel->setExportPanelListener(nullptr);
+            exportPanel->FastExportPressed();
+            exportPanel->setExportPanelListener(this);
+        }
         tbl->developRequested (mselected, true);
     }
 
@@ -961,7 +966,7 @@ void FileBrowser::menuItemActivated (Gtk::MenuItem* m)
         }
 
         queue_draw ();
-    } else if (m == execcustprof) {
+    } else if (m == resetdefaultprof) {
         if (!mselected.empty() && bppcl) {
             bppcl->beginBatchPParamsChange(mselected.size());
         }
@@ -1140,9 +1145,12 @@ bool FileBrowser::keyPressed (GdkEventKey* event)
     } else if (event->keyval == GDK_KEY_Delete && shift) {
         menuItemActivated (untrash);
         return true;
-    } else if ((event->keyval == GDK_KEY_B || event->keyval == GDK_KEY_b) && ctrl) {
+    } else if ((event->keyval == GDK_KEY_B || event->keyval == GDK_KEY_b) && ctrl && !shift) {
         menuItemActivated (develop);
         return true;
+    } else if ((event->keyval == GDK_KEY_B || event->keyval == GDK_KEY_b) && ctrl && shift) {
+        menuItemActivated (developfast);
+        return true;
     } else if ((event->keyval == GDK_KEY_A || event->keyval == GDK_KEY_a) && ctrl) {
         menuItemActivated (selall);
         return true;
@@ -1338,7 +1346,7 @@ void FileBrowser::applyMenuItemActivated (ProfileStoreLabel *label)
 {
     MYREADERLOCK(l, entryRW);
 
-    const rtengine::procparams::PartialProfile* partProfile = profileStore.getProfile (label->entry);
+    const rtengine::procparams::PartialProfile* partProfile = ProfileStore::getInstance()->getProfile (label->entry);
 
     if (partProfile->pparams && !selected.empty()) {
         if (bppcl) {
@@ -1368,7 +1376,7 @@ void FileBrowser::applyPartialMenuItemActivated (ProfileStoreLabel *label)
         }
     }
 
-    const rtengine::procparams::PartialProfile* srcProfiles = profileStore.getProfile (label->entry);
+    const rtengine::procparams::PartialProfile* srcProfiles = ProfileStore::getInstance()->getProfile (label->entry);
 
     if (srcProfiles->pparams) {
 
@@ -1496,11 +1504,11 @@ bool FileBrowser::checkFilter (ThumbBrowserEntryBase* entryb)   // true -> entry
         int iFilenameMatch = 0;
         std::vector<Glib::ustring> vFilterStrings = Glib::Regex::split_simple(",", decodedQueryFileName.uppercase());
 
-        for(int i = 0; i < vFilterStrings.size(); i++) {
+        for(size_t i = 0; i < vFilterStrings.size(); i++) {
             // ignore empty vFilterStrings. Otherwise filter will always return true if
             // e.g. filter.queryFileName ends on "," and will stop being a filter
             if (!vFilterStrings.at(i).empty()) {
-                if (FileName.find(vFilterStrings.at(i)) != -1) {
+                if (FileName.find(vFilterStrings.at(i)) != Glib::ustring::npos) {
                     iFilenameMatch++;
                 }
             }
@@ -1906,12 +1914,6 @@ void FileBrowser::openNextPreviousEditorImage (Glib::ustring fname, eRTNav nextP
     }
 }
 
-int refreshThumbImagesUI (void* data)
-{
-    (static_cast<FileBrowser*>(data))->_thumbRearrangementNeeded ();
-    return 0;
-}
-
 void FileBrowser::_thumbRearrangementNeeded ()
 {
     refreshThumbImages ();  // arrangeFiles is NOT enough
@@ -1919,8 +1921,13 @@ void FileBrowser::_thumbRearrangementNeeded ()
 
 void FileBrowser::thumbRearrangementNeeded ()
 {
-    // refreshThumbImagesUI will handle thread safety itself
-    g_idle_add (refreshThumbImagesUI, this);
+    const auto func = [](gpointer data) -> gboolean {
+        static_cast<FileBrowser*>(data)->_thumbRearrangementNeeded();
+
+        return FALSE;
+    };
+
+    idle_register.add(func, this);
 }
 
 void FileBrowser::selectionChanged ()
@@ -1975,7 +1982,7 @@ void FileBrowser::updateProfileList ()
     // submenu applmenu
     int p = 0;
 
-    const std::vector<const ProfileStoreEntry*> *profEntries = profileStore.getFileList();  // lock and get a pointer to the profiles' list
+    const std::vector<const ProfileStoreEntry*> *profEntries = ProfileStore::getInstance()->getFileList();  // lock and get a pointer to the profiles' list
 
     std::map<unsigned short /* folderId */, Gtk::Menu*> subMenuList;  // store the Gtk::Menu that Gtk::MenuItem will have to be attached to
 
@@ -2060,7 +2067,7 @@ void FileBrowser::updateProfileList ()
         applypartprof->set_submenu (*(subMenuList.at(0)));
     }
 
-    profileStore.releaseFileList();
+    ProfileStore::getInstance()->releaseFileList();
     subMenuList.clear();
 }
 
