@@ -38,7 +38,7 @@ Glib::RefPtr<Gdk::Pixbuf> FileBrowserEntry::recentlySavedIcon;
 Glib::RefPtr<Gdk::Pixbuf> FileBrowserEntry::enqueuedIcon;
 
 FileBrowserEntry::FileBrowserEntry (Thumbnail* thm, const Glib::ustring& fname)
-    : ThumbBrowserEntryBase (fname), wasInside(false), iatlistener(nullptr), cropgl(nullptr), state(SNormal)
+    : ThumbBrowserEntryBase (fname), wasInside(false), iatlistener(nullptr), cropgl(nullptr), state(SNormal), crop_custom_ratio(0.f)
 {
     thumbnail = thm;
 
@@ -67,6 +67,7 @@ FileBrowserEntry::FileBrowserEntry (Thumbnail* thm, const Glib::ustring& fname)
 
 FileBrowserEntry::~FileBrowserEntry ()
 {
+    idle_register.destroy();
 
     // so jobs arriving now do nothing
     if (feih->pending) {
@@ -176,39 +177,6 @@ void FileBrowserEntry::procParamsChanged (Thumbnail* thm, int whoChangedIt)
     }
 }
 
-struct tiupdate {
-    FileBrowserEntryIdleHelper* feih;
-    rtengine::IImage8* img;
-    double scale;
-    rtengine::procparams::CropParams cropParams;
-};
-
-int updateImageUI (void* data)
-{
-
-    tiupdate* params = static_cast<tiupdate*>(data);
-    FileBrowserEntryIdleHelper* feih = params->feih;
-
-    if (feih->destroyed) {
-        if (feih->pending == 1) {
-            delete feih;
-        } else {
-            feih->pending--;
-        }
-
-        params->img->free ();
-        delete params;
-        return 0;
-    }
-
-    feih->fbentry->_updateImage (params->img, params->scale, params->cropParams);
-    feih->pending--;
-
-    delete params;
-
-    return 0;
-}
-
 void FileBrowserEntry::updateImage (rtengine::IImage8* img, double scale, rtengine::procparams::CropParams cropParams)
 {
 
@@ -225,16 +193,51 @@ void FileBrowserEntry::updateImage (rtengine::IImage8* img, double scale, rtengi
         feih->pending++;
     }
 
-    tiupdate* param = new tiupdate ();
-    param->feih = feih;
-    param->img = img;
-    param->scale = scale;
-    param->cropParams = cropParams;
+    struct tiupdate {
+        FileBrowserEntryIdleHelper* feih;
+        rtengine::IImage8* img;
+        double scale;
+        rtengine::procparams::CropParams cropParams;
+    };
+
+    tiupdate* param = new tiupdate{
+        feih,
+        img,
+        scale,
+        cropParams
+    };
+
 #if __GNUC__ == 4 && __GNUC_MINOR__ == 8 && defined( WIN32 ) && defined(__x86_64__)
-    g_idle_add_full (G_PRIORITY_DEFAULT, updateImageUI, param, NULL);
+    const gint priority = G_PRIORITY_DEFAULT;
 #else
-    g_idle_add_full (G_PRIORITY_LOW, updateImageUI, param, nullptr);
+    const gint priority = G_PRIORITY_LOW;
 #endif
+
+    const auto func = [](gpointer data) -> gboolean {
+        tiupdate* const params = static_cast<tiupdate*>(data);
+        FileBrowserEntryIdleHelper* const feih = params->feih;
+
+        if (feih->destroyed) {
+            if (feih->pending == 1) {
+                delete feih;
+            } else {
+                feih->pending--;
+            }
+
+            params->img->free ();
+            delete params;
+            return 0;
+        }
+
+        feih->fbentry->_updateImage (params->img, params->scale, params->cropParams);
+        feih->pending--;
+
+        delete params;
+
+        return FALSE;
+    };
+
+    idle_register.add(func, param, priority);
 }
 
 void FileBrowserEntry::_updateImage (rtengine::IImage8* img, double s, rtengine::procparams::CropParams cropParams)
@@ -319,24 +322,24 @@ bool FileBrowserEntry::motionNotify (int x, int y)
         int oy = cropParams.y;
         cropParams.y = action_y + (y - press_y) / scale;
         cropParams.h += oy - cropParams.y;
-        cropgl->cropHeight1Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropHeight1Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SResizeH2 && cropgl) {
         cropParams.h = action_y + (y - press_y) / scale;
-        cropgl->cropHeight2Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropHeight2Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SResizeW1 && cropgl) {
         int ox = cropParams.x;
         cropParams.x = action_x + (x - press_x) / scale;
         cropParams.w += ox - cropParams.x;
-        cropgl->cropWidth1Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropWidth1Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SResizeW2 && cropgl) {
         cropParams.w = action_x + (x - press_x) / scale;
-        cropgl->cropWidth2Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropWidth2Resized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SResizeTL && cropgl) {
@@ -346,7 +349,7 @@ bool FileBrowserEntry::motionNotify (int x, int y)
         int oy = cropParams.y;
         cropParams.y = action_y + (y - press_y) / scale;
         cropParams.h += oy - cropParams.y;
-        cropgl->cropTopLeftResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropTopLeftResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SResizeTR && cropgl) {
@@ -354,7 +357,7 @@ bool FileBrowserEntry::motionNotify (int x, int y)
         int oy = cropParams.y;
         cropParams.y = action_y + (y - press_y) / scale;
         cropParams.h += oy - cropParams.y;
-        cropgl->cropTopRightResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropTopRightResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SResizeBL && cropgl) {
@@ -362,13 +365,13 @@ bool FileBrowserEntry::motionNotify (int x, int y)
         cropParams.x = action_x + (x - press_x) / scale;
         cropParams.w += ox - cropParams.x;
         cropParams.h = action_y + (y - press_y) / scale;
-        cropgl->cropBottomLeftResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropBottomLeftResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SResizeBR && cropgl) {
         cropParams.w = action_x + (x - press_x) / scale;
         cropParams.h = action_y + (y - press_y) / scale;
-        cropgl->cropBottomRightResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h);
+        cropgl->cropBottomRightResized (cropParams.x, cropParams.y, cropParams.w, cropParams.h, crop_custom_ratio);
         updateBackBuffer ();
         parent->redrawNeeded (this);
     } else if (state == SCropMove && cropgl) {
@@ -418,8 +421,17 @@ bool FileBrowserEntry::pressNotify   (int button, int type, int bstate, int x, i
     int ix = x - startx - ofsX;
     int iy = y - starty - ofsY;
 
+    if (tm == TMNone) {
+        return b;
+    }
+
+    crop_custom_ratio = 0.f;
+
     if (!b && selected && inside (x, y)) {
         if (button == 1 && type == GDK_BUTTON_PRESS && state == SNormal) {
+            if ((bstate & GDK_SHIFT_MASK) && cropParams.w > 0 && cropParams.h > 0) {
+                crop_custom_ratio = float(cropParams.w) / float(cropParams.h);
+            }
             if (onArea (CropTopLeft, ix, iy)) {
                 state = SResizeTL;
                 press_x = x;
@@ -631,6 +643,7 @@ bool FileBrowserEntry::onArea (CursorArea a, int x, int y)
                y1 < cropParams.y + cropParams.h - 1 &&
                x1 > cropParams.x &&
                x1 < cropParams.x + cropParams.w - 1;
+    default: /* do nothing */ ;
     }
 
     return false;
@@ -719,7 +732,7 @@ void FileBrowserEntry::drawStraightenGuide (Cairo::RefPtr<Cairo::Context> cr)
     if (action_x != press_x || action_y != press_y) {
         double arg = (press_x - action_x) / sqrt(double((press_x - action_x) * (press_x - action_x) + (press_y - action_y) * (press_y - action_y)));
         double sol1, sol2;
-        double pi = M_PI;
+        double pi = rtengine::RT_PI;
 
         if (press_y > action_y) {
             sol1 = acos(arg) * 180 / pi;
