@@ -30,7 +30,7 @@ class FlatCurveEditorSubGroup: public CurveEditorSubGroup
     friend class FlatCurveEditor;
 
 protected:
-    Gtk::VBox* CPointsCurveBox;
+    Gtk::Grid* CPointsCurveGrid;
 
     MyFlatCurve* CPointsCurve;
 
@@ -54,7 +54,7 @@ public:
     void refresh(CurveEditor *curveToRefresh);
     void editModeSwitchedOff();
     void pipetteMouseOver(EditDataProvider *provider, int modifierKey);
-    void pipetteButton1Pressed(EditDataProvider *provider, int modifierKey);
+    bool pipetteButton1Pressed(EditDataProvider *provider, int modifierKey);
     void pipetteButton1Released(EditDataProvider *provider);
     void pipetteDrag(EditDataProvider *provider, int modifierKey);
     void showCoordinateAdjuster(CoordinateProvider *provider);
