@@ -22,6 +22,7 @@
 #include "options.h"
 #include "../rtengine/rt_math.h"
 #include "../rtengine/utils.h"
+#include "../rtengine/icons.h"
 #include "rtimage.h"
 #include "multilangmgr.h"
 
@@ -37,12 +38,49 @@ Glib::RefPtr<Gdk::Pixbuf> MyExpander::disabledPBuf;
 Glib::RefPtr<Gdk::Pixbuf> MyExpander::openedPBuf;
 Glib::RefPtr<Gdk::Pixbuf> MyExpander::closedPBuf;
 
-guint add_idle (GSourceFunc function, gpointer data)
+IdleRegister::~IdleRegister()
 {
-    return gdk_threads_add_idle(function, data);
-    //gtk_main_iteration_do(false);
+    destroy();
 }
 
+void IdleRegister::add(GSourceFunc function, gpointer data, gint priority)
+{
+    const auto dispatch = [](gpointer data) -> gboolean {
+        DataWrapper* const data_wrapper = static_cast<DataWrapper*>(data);
+
+        if (!data_wrapper->function(data_wrapper->data)) {
+            data_wrapper->self->mutex.lock();
+            data_wrapper->self->ids.erase(data_wrapper);
+            data_wrapper->self->mutex.unlock();
+
+            delete data_wrapper;
+            return FALSE;
+        }
+
+        return TRUE;
+    };
+
+    DataWrapper* const data_wrapper = new DataWrapper{
+        this,
+        function,
+        data
+    };
+
+    mutex.lock();
+    ids[data_wrapper] = gdk_threads_add_idle_full(priority, dispatch, data_wrapper, nullptr);
+    mutex.unlock();
+}
+
+void IdleRegister::destroy()
+{
+    mutex.lock();
+    for (const auto& id : ids) {
+        g_source_remove(id.second);
+        delete id.first;
+    }
+    ids.clear();
+    mutex.unlock();
+}
 
 /*
 gboolean giveMeAGo(void* data) {
@@ -169,34 +207,6 @@ void thumbInterp (const unsigned char* src, int sw, int sh, unsigned char* dst,
     }
 }
 
-Glib::ustring removeExtension (const Glib::ustring& filename)
-{
-
-    Glib::ustring bname = Glib::path_get_basename(filename);
-    size_t lastdot = bname.find_last_of ('.');
-    size_t lastwhitespace = bname.find_last_of (" \t\f\v\n\r");
-
-    if (lastdot != bname.npos && (lastwhitespace == bname.npos || lastdot > lastwhitespace)) {
-        return filename.substr (0, filename.size() - (bname.size() - lastdot));
-    } else {
-        return filename;
-    }
-}
-
-Glib::ustring getExtension (const Glib::ustring& filename)
-{
-
-    Glib::ustring bname = Glib::path_get_basename(filename);
-    size_t lastdot = bname.find_last_of ('.');
-    size_t lastwhitespace = bname.find_last_of (" \t\f\v\n\r");
-
-    if (lastdot != bname.npos && (lastwhitespace == bname.npos || lastdot > lastwhitespace)) {
-        return filename.substr (filename.size() - (bname.size() - lastdot) + 1, filename.npos);
-    } else {
-        return "";
-    }
-}
-
 bool confirmOverwrite (Gtk::Window& parent, const std::string& filename)
 {
     bool safe = true;
@@ -542,11 +552,11 @@ void ExpanderBox::hideBox()
 
 void MyExpander::init()
 {
-    inconsistentPBuf = Gdk::Pixbuf::create_from_file(RTImage::findIconAbsolutePath("expanderInconsistent.png"));
-    enabledPBuf = Gdk::Pixbuf::create_from_file(RTImage::findIconAbsolutePath("expanderEnabled.png"));
-    disabledPBuf = Gdk::Pixbuf::create_from_file(RTImage::findIconAbsolutePath("expanderDisabled.png"));
-    openedPBuf = Gdk::Pixbuf::create_from_file(RTImage::findIconAbsolutePath("expanderOpened.png"));
-    closedPBuf = Gdk::Pixbuf::create_from_file(RTImage::findIconAbsolutePath("expanderClosed.png"));
+    inconsistentPBuf = Gdk::Pixbuf::create_from_file(rtengine::findIconAbsolutePath("expanderInconsistent.png"));
+    enabledPBuf = Gdk::Pixbuf::create_from_file(rtengine::findIconAbsolutePath("expanderEnabled.png"));
+    disabledPBuf = Gdk::Pixbuf::create_from_file(rtengine::findIconAbsolutePath("expanderDisabled.png"));
+    openedPBuf = Gdk::Pixbuf::create_from_file(rtengine::findIconAbsolutePath("expanderOpened.png"));
+    closedPBuf = Gdk::Pixbuf::create_from_file(rtengine::findIconAbsolutePath("expanderClosed.png"));
 }
 
 MyExpander::MyExpander(bool useEnabled, Gtk::Widget* titleWidget) :
@@ -1440,8 +1450,6 @@ bool BackBuffer::setDrawRectangle(Cairo::Format format, int newX, int newY, int
  */
 void BackBuffer::copyRGBCharData(const unsigned char *srcData, int srcX, int srcY, int srcW, int srcH, int srcRowStride, int dstX, int dstY)
 {
-    const unsigned char *src;
-    unsigned char *dst;
     unsigned char r, g, b;
 
     if (!surface) {
@@ -1458,15 +1466,15 @@ void BackBuffer::copyRGBCharData(const unsigned char *srcData, int srcX, int src
         return;
     }
 
-    for (unsigned int i = 0; i < (unsigned int)(srcH); ++i) {
+    for (int i = 0; i < srcH; ++i) {
         if (dstY + i >= surfH) {
             break;
         }
 
-        src = srcData + i * srcRowStride;
-        dst = dstData + ((dstY + i) * surfW + dstX) * 4;
+        const unsigned char *src = srcData + i * srcRowStride;
+        unsigned char *dst = dstData + ((dstY + i) * surfW + dstX) * 4;
 
-        for (unsigned int j = 0; j < (unsigned int)(srcW); ++j) {
+        for (int j = 0; j < srcW; ++j) {
             if (dstX + j >= surfW) {
                 break;
             }
@@ -1600,8 +1608,8 @@ void BackBuffer::copySurface(Cairo::RefPtr<Cairo::Context> crDest, Gdk::Rectangl
         int offsetY = rtengine::LIM<int>(offset.y, 0, surface->get_height());
 
         // now copy the off-screen Surface to the destination Surface
-        int srcSurfW = surface->get_width();
-        int srcSurfH = surface->get_height();
+        // int srcSurfW = surface->get_width();
+        // int srcSurfH = surface->get_height();
         //printf("srcSurf:  w: %d, h: %d\n", srcSurfW, srcSurfH);
         crDest->set_line_width(0.);
 
