@@ -19,26 +19,50 @@
 #ifndef __GUI_UTILS_
 #define __GUI_UTILS_
 
+#include <map>
+
 #include <gtkmm.h>
+
 #include <cairomm/cairomm.h>
-#include "../rtengine/rtengine.h"
+
 #include "../rtengine/coord.h"
+#include "../rtengine/noncopyable.h"
+#include "../rtengine/rtengine.h"
+
 #include "rtimage.h"
-#include <sstream>
-#include <iostream>
+
+// for convenience...
+#include "pathutils.h"
+
 
 Glib::ustring escapeHtmlChars(const Glib::ustring &src);
 bool removeIfThere (Gtk::Container* cont, Gtk::Widget* w, bool increference = true);
 void thumbInterp (const unsigned char* src, int sw, int sh, unsigned char* dst, int dw, int dh);
-Glib::ustring removeExtension (const Glib::ustring& filename);
-Glib::ustring getExtension (const Glib::ustring& filename);
 bool confirmOverwrite (Gtk::Window& parent, const std::string& filename);
 void writeFailed (Gtk::Window& parent, const std::string& filename);
 void drawCrop (Cairo::RefPtr<Cairo::Context> cr, int imx, int imy, int imw, int imh, int startx, int starty, double scale, const rtengine::procparams::CropParams& cparams, bool drawGuide = true, bool useBgColor = true, bool fullImageVisible = true);
 gboolean acquireGUI(void* data);
 void setExpandAlignProperties(Gtk::Widget *widget, bool hExpand, bool vExpand, enum Gtk::Align hAlign, enum Gtk::Align vAlign);
 
-guint add_idle (GSourceFunc function, gpointer data);
+class IdleRegister final :
+    public rtengine::NonCopyable
+{
+public:
+    ~IdleRegister();
+
+    void add(GSourceFunc function, gpointer data, gint priority = G_PRIORITY_DEFAULT_IDLE);
+    void destroy();
+
+private:
+    struct DataWrapper {
+        IdleRegister* const self;
+        GSourceFunc function;
+        gpointer data;
+    };
+
+    std::map<const DataWrapper*, guint> ids;
+    MyMutex mutex;
+};
 
 // TODO: The documentation says gdk_threads_enter and gdk_threads_leave should be replaced
 // by g_main_context_invoke(), g_idle_add() and related functions, but this will require more extensive changes.
@@ -94,7 +118,7 @@ public:
 class ConnectionBlocker
 {
 public:
-    explicit ConnectionBlocker (Gtk::Widget *associatedWidget, sigc::connection& connection) : connection (associatedWidget ? &connection : nullptr)
+    explicit ConnectionBlocker (Gtk::Widget *associatedWidget, sigc::connection& connection) : connection (associatedWidget ? &connection : nullptr), wasBlocked(false)
     {
         if (this->connection) {
             wasBlocked = connection.block();
@@ -295,15 +319,18 @@ public:
 class MyComboBoxText : public Gtk::ComboBoxText
 {
     int naturalWidth, minimumWidth;
+    sigc::connection myConnection;
 
     bool on_scroll_event (GdkEventScroll* event);
     void get_preferred_width_vfunc (int &minimum_width, int &natural_width) const;
     void get_preferred_width_for_height_vfunc (int height, int &minimum_width, int &natural_width) const;
 
 public:
-    MyComboBoxText (bool has_entry = false);
+    explicit MyComboBoxText (bool has_entry = false);
 
     void setPreferredWidth (int minimum_width, int natural_width);
+    void connect(const sigc::connection &connection) { myConnection = connection; }
+    void block(bool blocked) { myConnection.block(blocked); }
 };
 
 /**
@@ -416,7 +443,7 @@ private:
     void get_preferred_width_for_height_vfunc (int height, int &minimum_width, int &natural_width) const;
 
 public:
-    MyProgressBar(int width);
+    explicit MyProgressBar(int width);
     MyProgressBar();
 
     void setPreferredWidth(int width);
