@@ -22,6 +22,7 @@
 #include <gtkmm.h>
 #include "toolpanel.h"
 #include "guiutils.h"
+#include "lensgeom.h"
 
 class LensProfilePanel : public ToolParamBlock, public FoldableToolPanel
 {
@@ -38,13 +39,14 @@ protected:
     void updateDisabled(bool enable);
     bool allowFocusDep;
     bool isRaw;
+    LensGeometry *lensgeomLcpFill;
 
 public:
 
     LensProfilePanel ();
 
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = NULL);
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = NULL);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = nullptr);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = nullptr);
     void setRawMeta     (bool raw, const rtengine::ImageMetaData* pMeta);
 
     void onLCPFileChanged ();
@@ -52,6 +54,10 @@ public:
     void onUseDistChanged();
     void onUseVignChanged();
     void onUseCAChanged();
+    void setLensGeomRef( LensGeometry *foo)
+    {
+        lensgeomLcpFill = foo ;
+    };
 };
 
 #endif
