@@ -456,13 +456,13 @@ void MyFlatCurve::draw ()
             double x = double(graphX + 1) + innerW * curve.x.at(i); // project (curve.x.at(i), 0, 1, graphW);
             double y = double(graphY - 1) - innerH * curve.y.at(i); // project (curve.y.at(i), 0, 1, graphH);
 
-            cr->arc (x, y, (double)RADIUS, 0, 2 * M_PI);
+            cr->arc (x, y, (double)RADIUS, 0, 2 * rtengine::RT_PI);
             cr->fill ();
 
             if (i == edited_point) {
                 cr->set_source_rgb (1.0, 0.0, 0.0);
                 cr->set_line_width(2.);
-                cr->arc (x, y, RADIUS + 3.5, 0, 2 * M_PI);
+                cr->arc (x, y, RADIUS + 3.5, 0, 2 * rtengine::RT_PI);
                 cr->stroke();
                 cr->set_line_width(1.);
             }
@@ -711,7 +711,7 @@ bool MyFlatCurve::handleEvents (GdkEvent* event)
                             setDirty(true);
                             draw ();
                             std::vector<CoordinateAdjuster::Boundaries> newBoundaries(4);
-                            unsigned int size = curve.x.size();
+                            int size = curve.x.size();
 
                             if      (edited_point == 0)      {
                                 newBoundaries.at(0).minVal = 0.;
@@ -761,7 +761,7 @@ bool MyFlatCurve::handleEvents (GdkEvent* event)
                         setDirty(true);
                         draw ();
                         std::vector<CoordinateAdjuster::Boundaries> newBoundaries(4);
-                        unsigned int size = curve.x.size();
+                        int size = curve.x.size();
 
                         if      (edited_point == 0)      {
                             newBoundaries.at(0).minVal = 0.;
@@ -1194,6 +1194,7 @@ void MyFlatCurve::pipetteMouseOver (CurveEditor *ce, EditDataProvider *provider,
         // occurs when leaving the preview area -> cleanup the curve editor
         pipetteR = pipetteG = pipetteB = -1.f;
         lit_point = -1;
+        editedHandle = FCT_EditedHandle_None;
         return;
     }
 
@@ -1544,7 +1545,7 @@ void MyFlatCurve::movePoint(bool moveX, bool moveY, bool pipetteDrag)
             }
 
             if (curve.y.size() > 2) {
-                if (lit_point == (curve.y.size() - 1)) {
+                if (lit_point == int(curve.y.size()) - 1) {
                     if (snapCoordinateY(curve.y.at(0), ugpY)) {
                         snapToElmt = 0;
                     }
