@@ -2,11 +2,19 @@
 #define _PPVERSION_
 
 // This number has to be incremented whenever the PP3 file format is modified or the behaviour of a tool changes
-#define PPVERSION 321
+#define PPVERSION 326
 #define PPVERSION_AEXP 301 //value of PPVERSION when auto exposure algorithm was modified
 
 /*
   Log of version changes
+   326  2015-07-26
+        [Exposure] Added 'Perceptual' tone curve mode
+   325  2015-07-23
+        [Exposure] [RGB Curves] [B&W] Normalized RGB pipeline curve gammas to sRGB (before it was a mix between sRGB and 1.0 and depended on file format)
+   323  2015-10-05
+        [Exposure] Added 'Luminance' tone curve mode
+   322  2015-01-31
+        [Wavelet] new tool using wavelet levels
    321  2014-08-17
         [Film Simulation] new  tool using HALDCLUT files
    320  2014-07-02  (yes, same version number... this is an error due to a wrong version number set in comment of previous change)
