@@ -24,6 +24,7 @@
 #include "options.h"
 #include <vector>
 #include "rtwindow.h"
+#include "dynamicprofilepanel.h"
 
 class Preferences : public Gtk::Dialog, public ProfileStoreListener
 {
@@ -176,8 +177,7 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener
     Gtk::Button*      behSetAll;
     Gtk::CheckButton* chOverwriteOutputFile;
 
-    Gtk::CheckButton* saveParamsFile;
-    Gtk::CheckButton* saveParamsCache;
+    Gtk::ComboBoxText* saveParamsPreference;
     Gtk::CheckButton* useBundledProfiles;
     Gtk::ComboBoxText* loadParamsPreference;
     Gtk::ComboBoxText* editorLayout;
@@ -201,14 +201,19 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener
     Gtk::CheckButton* ckbHideTPVScrollbar;
     Gtk::CheckButton* ckbUseIconNoText;
 
+    DynamicProfilePanel *dynProfilePanel;
+
     Glib::ustring storedValueRaw;
     Glib::ustring storedValueImg;
 
     Options moptions;
-    sigc::connection tconn, sconn, fconn, addc, setc, dfconn, ffconn, bpconn, rpconn, ipconn;
+    sigc::connection tconn, sconn, fconn, cpfconn, addc, setc, dfconn, ffconn, bpconn, rpconn, ipconn;
     sigc::connection autoMonProfileConn, sndEnableConn, langAutoDetectConn, autocielabConn;
     Glib::ustring initialTheme;
-    Glib::ustring initialFont;
+    Glib::ustring initialFontFamily;
+    int initialFontSize;
+    bool newFont;
+    bool newCPFont;
 
     void fillPreferences ();
     void storePreferences ();
@@ -219,6 +224,7 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener
     void workflowUpdate();
     void themeChanged  ();
     void fontChanged   ();
+    void cpFontChanged ();
     void forRAWComboChanged ();
     void forImageComboChanged ();
     void layoutComboChanged ();
@@ -239,6 +245,7 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener
     Gtk::Widget* getBatchProcPanel ();
     Gtk::Widget* getPerformancePanel ();
     Gtk::Widget* getSoundPanel ();
+    Gtk::Widget* getDynProfilePanel ();
 
 public:
     explicit Preferences (RTWindow *rtwindow);
